@@ -44,7 +44,7 @@ struct _GthCatalogPrivate {
 };
 
 
-static gpointer parent_class = NULL;
+G_DEFINE_TYPE (GthCatalog, gth_catalog, G_TYPE_OBJECT)
 
 
 static void
@@ -66,7 +66,7 @@ gth_catalog_finalize (GObject *object)
 		catalog->priv = NULL;
 	}
 
-	G_OBJECT_CLASS (parent_class)->finalize (object);
+	G_OBJECT_CLASS (gth_catalog_parent_class)->finalize (object);
 }
 
 
@@ -232,9 +232,7 @@ gth_catalog_class_init (GthCatalogClass *class)
 {
 	GObjectClass *object_class;
 
-	parent_class = g_type_class_peek_parent (class);
 	object_class = (GObjectClass*) class;
-
 	object_class->finalize = gth_catalog_finalize;
 
 	class->create_root = base_create_root;
@@ -253,34 +251,6 @@ gth_catalog_init (GthCatalog *catalog)
 }
 
 
-GType
-gth_catalog_get_type (void)
-{
-	static GType type = 0;
-
-	if (! type) {
-		GTypeInfo type_info = {
-			sizeof (GthCatalogClass),
-			NULL,
-			NULL,
-			(GClassInitFunc) gth_catalog_class_init,
-			NULL,
-			NULL,
-			sizeof (GthCatalog),
-			0,
-			(GInstanceInitFunc) gth_catalog_init
-		};
-
-		type = g_type_register_static (G_TYPE_OBJECT,
-					       "GthCatalog",
-					       &type_info,
-					       0);
-	}
-
-	return type;
-}
-
-
 GthCatalog *
 gth_catalog_new (void)
 {
@@ -672,8 +642,6 @@ get_display_name (GFile       *file,
 		}
 	}
 
-	g_free (basename);
-
 	return g_string_free (display_name, FALSE);
 }
 
@@ -707,8 +675,6 @@ get_edit_name (GFile       *file,
 			g_string_append (display_name, name);
 	}
 
-	g_free (basename);
-
 	return g_string_free (display_name, FALSE);
 }
 
@@ -729,8 +695,6 @@ update_standard_attributes (GFile       *file,
 		sort_order_s = gth_datetime_strftime (date_time, "%Y%m%d");
 		sort_order = atoi (sort_order_s);
 		g_file_info_set_sort_order (info, sort_order);
-
-		g_free (sort_order_s);
 	}
 	else if (g_file_info_get_attribute_boolean (info, "gthumb::no-child"))
 		g_file_info_set_sort_order (info, 99999999);
@@ -858,7 +822,6 @@ gth_catalog_file_to_gio_file (GFile *file)
 			full_uri = g_strconcat (base_uri, part ? "/" : NULL, part, NULL);
 			gio_file = g_file_new_for_uri (full_uri);
 
-			g_free (full_uri);
 			g_free (base_uri);
 			g_object_unref (base);
 		}
@@ -1195,8 +1158,7 @@ gth_catalog_save (GthCatalog *catalog)
 	gio_file = gth_catalog_file_to_gio_file (file);
 
 	gio_parent = g_file_get_parent (gio_file);
-	if (gio_parent != NULL)
-		g_file_make_directory_with_parents (gio_parent, NULL, NULL);
+	g_file_make_directory_with_parents (gio_parent, NULL, NULL);
 	data = gth_catalog_to_data (catalog, &size);
 	if (! g_write_file (gio_file,
 			    FALSE,
@@ -1236,6 +1198,6 @@ gth_catalog_save (GthCatalog *catalog)
 	}
 
 	g_free (data);
-	_g_object_unref (gio_parent);
+	g_object_unref (gio_parent);
 	g_object_unref (gio_file);
 }
