@@ -37,7 +37,7 @@ struct _GthFileSourceCatalogsPrivate
 };
 
 
-static gpointer parent_class = NULL;
+G_DEFINE_TYPE (GthFileSourceCatalogs, gth_file_source_catalogs, GTH_TYPE_FILE_SOURCE)
 
 
 static GList *
@@ -71,16 +71,14 @@ update_file_info (GthFileSource *file_source,
 		  GFile         *catalog_file,
 		  GFileInfo     *info)
 {
-	char  *uri;
-	GIcon *icon = NULL;
+	char *uri;
 
 	uri = g_file_get_uri (catalog_file);
 
 	if (g_str_has_suffix (uri, ".gqv") || g_str_has_suffix (uri, ".catalog")) {
 		g_file_info_set_file_type (info, G_FILE_TYPE_DIRECTORY);
 		g_file_info_set_content_type (info, "gthumb/catalog");
-		icon = g_themed_icon_new ("file-catalog");
-		g_file_info_set_icon (info, icon);
+		g_file_info_set_icon (info, g_themed_icon_new ("file-catalog"));
 		g_file_info_set_sort_order (info, 1);
 		g_file_info_set_attribute_boolean (info, "gthumb::no-child", TRUE);
 		gth_catalog_update_standard_attributes (catalog_file, info);
@@ -88,8 +86,7 @@ update_file_info (GthFileSource *file_source,
 	else if (g_str_has_suffix (uri, ".search")) {
 		g_file_info_set_file_type (info, G_FILE_TYPE_DIRECTORY);
 		g_file_info_set_content_type (info, "gthumb/search");
-		icon = g_themed_icon_new ("file-search");
-		g_file_info_set_icon (info, icon);
+		g_file_info_set_icon (info, g_themed_icon_new ("file-search"));
 		g_file_info_set_sort_order (info, 1);
 		g_file_info_set_attribute_boolean (info, "gthumb::no-child", TRUE);
 		gth_catalog_update_standard_attributes (catalog_file, info);
@@ -97,14 +94,12 @@ update_file_info (GthFileSource *file_source,
 	else {
 		g_file_info_set_file_type (info, G_FILE_TYPE_DIRECTORY);
 		g_file_info_set_content_type (info, "gthumb/library");
-		icon = g_themed_icon_new ("file-library");
-		g_file_info_set_icon (info, icon);
+		g_file_info_set_icon (info, g_themed_icon_new ("file-library"));
 		g_file_info_set_sort_order (info, 0);
 		g_file_info_set_attribute_boolean (info, "gthumb::no-child", FALSE);
 		gth_catalog_update_standard_attributes (catalog_file, info);
 	}
 
-	_g_object_unref (icon);
 	g_free (uri);
 }
 
@@ -1521,7 +1516,7 @@ gth_file_source_catalogs_finalize (GObject *object)
 		catalogs->priv = NULL;
 	}
 
-	G_OBJECT_CLASS (parent_class)->finalize (object);
+	G_OBJECT_CLASS (gth_file_source_catalogs_parent_class)->finalize (object);
 }
 
 
@@ -1531,11 +1526,10 @@ gth_file_source_catalogs_class_init (GthFileSourceCatalogsClass *class)
 	GObjectClass       *object_class;
 	GthFileSourceClass *file_source_class;
 
-	parent_class = g_type_class_peek_parent (class);
 	object_class = (GObjectClass*) class;
-	file_source_class = (GthFileSourceClass*) class;
-
 	object_class->finalize = gth_file_source_catalogs_finalize;
+
+	file_source_class = (GthFileSourceClass*) class;
 	file_source_class->get_entry_points = get_entry_points;
 	file_source_class->to_gio_file = gth_file_source_catalogs_to_gio_file;
 	file_source_class->get_file_info = gth_file_source_catalogs_get_file_info;
@@ -1555,36 +1549,8 @@ gth_file_source_catalogs_class_init (GthFileSourceCatalogsClass *class)
 static void
 gth_file_source_catalogs_init (GthFileSourceCatalogs *catalogs)
 {
-	gth_file_source_add_scheme (GTH_FILE_SOURCE (catalogs), "catalog://");
+	gth_file_source_add_scheme (GTH_FILE_SOURCE (catalogs), "catalog");
 
 	catalogs->priv = g_new0 (GthFileSourceCatalogsPrivate, 1);
 	catalogs->priv->catalog = gth_catalog_new ();
 }
-
-
-GType
-gth_file_source_catalogs_get_type (void)
-{
-	static GType type = 0;
-
-	if (! type) {
-		GTypeInfo type_info = {
-			sizeof (GthFileSourceCatalogsClass),
-			NULL,
-			NULL,
-			(GClassInitFunc) gth_file_source_catalogs_class_init,
-			NULL,
-			NULL,
-			sizeof (GthFileSourceCatalogs),
-			0,
-			(GInstanceInitFunc) gth_file_source_catalogs_init
-		};
-
-		type = g_type_register_static (GTH_TYPE_FILE_SOURCE,
-					       "GthFileSourceCatalogs",
-					       &type_info,
-					       0);
-	}
-
-	return type;
-}
