@@ -171,6 +171,12 @@ const char *_KEYWORDS_TAG_NAMES[] = {
 	NULL
 };
 
+const char *_RATING_TAG_NAMES[] = {
+	"Xmp::xmp::Rating",
+	NULL
+};
+
+
 /* Some evil camera fill in the ImageDescription or UserComment fields
    with useless fluff. Try to filter these out, so they do not show up
    as comments */
@@ -287,23 +293,6 @@ create_metadata (const char *key,
 }
 
 
-static void
-add_string_list_to_metadata (GthMetadata            *metadata,
-			     const Exiv2::Metadatum &value)
-{
-	GList         *list = NULL;
-	GthStringList *string_list;
-
-	for (int i = 0; i < value.count(); i++)
-		list = g_list_prepend (list, g_strdup (value.toString(i).c_str()));
-	string_list = gth_string_list_new (g_list_reverse (list));
-	g_object_set (metadata, "string-list", string_list, NULL);
-
-	g_object_unref (string_list);
-	_g_string_list_free (list);
-}
-
-
 static void
 set_file_info (GFileInfo  *info,
 	       const char *key,
@@ -403,6 +392,7 @@ set_attribute_from_metadata (GFileInfo  *info,
 			     const char *attribute,
 			     GObject    *metadata)
 {
+	char *key;
 	char *description;
 	char *formatted_value;
 	char *raw_value;
@@ -412,6 +402,7 @@ set_attribute_from_metadata (GFileInfo  *info,
 		return;
 
 	g_object_get (metadata,
+		      "id", &key,
 		      "description", &description,
 		      "formatted", &formatted_value,
 		      "raw", &raw_value,
@@ -425,11 +416,6 @@ set_attribute_from_metadata (GFileInfo  *info,
 		       raw_value,
 		       NULL,
 		       type_name);
-
-	g_free (description);
-	g_free (formatted_value);
-	g_free (raw_value);
-	g_free (type_name);
 }
 
 
@@ -546,6 +532,7 @@ set_attributes_from_tagsets (GFileInfo *info)
 
 	set_attribute_from_tagset (info, "general::location", _LOCATION_TAG_NAMES);
 	set_string_list_attribute_from_tagset (info, "general::tags", _KEYWORDS_TAG_NAMES);
+	set_attribute_from_tagset (info, "general::rating", _RATING_TAG_NAMES);
 	set_attribute_from_tagset (info, "Embedded::Photo::DateTimeOriginal", _ORIGINAL_DATE_TAG_NAMES);
 	set_attribute_from_tagset (info, "Embedded::Image::Orientation", _ORIENTATION_TAG_NAMES);
 }
@@ -661,13 +648,6 @@ exiv2_read_metadata (Exiv2::Image::AutoPtr  image,
 						    raw_value.str().c_str(),
 						    "Xmp::Embedded",
 						    md->typeName());
-
-			if ((g_strcmp0 (md->typeName(), "XmpBag") == 0)
-			    || (g_strcmp0 (md->typeName(), "XmpSeq") == 0))
-			{
-				add_string_list_to_metadata (metadata, *md);
-			}
-
 			add_metadata_to_hash (table, metadata);
 			_g_object_unref (metadata);
 		}
@@ -711,7 +691,8 @@ exiv2_read_metadata_from_file (GFile         *file,
 				*error = g_error_new_literal (G_IO_ERROR, G_IO_ERROR_FAILED, _("Invalid file format"));
 			return FALSE;
 		}
-
+		// Set the log level to only show errors (and suppress warnings, informational and debug messages)
+		Exiv2::LogMsg::setLevel(Exiv2::LogMsg::error);
 		exiv2_read_metadata (image, info);
 	}
 	catch (Exiv2::AnyError& e) {
@@ -817,13 +798,6 @@ exiv2_read_sidecar (GFile     *file,
 							    raw_value.str().c_str(),
 							    "Xmp::Sidecar",
 							    md->typeName());
-
-				if ((g_strcmp0 (md->typeName(), "XmpBag") == 0)
-				    || (g_strcmp0 (md->typeName(), "XmpSeq") == 0))
-				{
-					add_string_list_to_metadata (metadata, *md);
-				}
-
 				add_metadata_to_hash (table, metadata);
 				_g_object_unref (metadata);
 			}
@@ -988,11 +962,13 @@ exiv2_write_metadata_private (Exiv2::Image::AutoPtr  image,
 	mandatory_string (ed, "Exif.Photo.ComponentsConfiguration", "1 2 3 0");
 	mandatory_string (ed, "Exif.Photo.FlashpixVersion", "48 49 48 48");
 
-	// Overwrite the software tag
+	// Overwrite the software tag if the image content was modified
 
-	if (software_name == NULL)
-		software_name = g_strconcat (g_get_application_name (), " ", VERSION, NULL);
-	ed["Exif.Image.Software"] = software_name;
+	if (g_file_info_get_attribute_boolean (info, "gth::file::image-changed")) {
+		if (software_name == NULL)
+			software_name = g_strconcat (g_get_application_name (), " ", VERSION, NULL);
+		ed["Exif.Image.ProcessingSoftware"] = software_name;
+	}
 
 	// Update the dimension tags with actual image values
 
@@ -1132,28 +1108,12 @@ exiv2_write_metadata_private (Exiv2::Image::AutoPtr  image,
 					}
 				}
 				else if (GTH_IS_METADATA (metadatum)) {
-					const char    *raw_value;
-					GthStringList *string_list;
-					GList         *scan;
+					const char *raw_value;
 
-					switch (gth_metadata_get_data_type (GTH_METADATA (metadatum))) {
-					case GTH_METADATA_TYPE_STRING:
-						raw_value = gth_metadata_get_raw (GTH_METADATA (metadatum));
-						if ((raw_value != NULL) && (strcmp (raw_value, "") != 0)) {
-							value->read (raw_value);
-							xd.add (xmp_key, value.get());
-						}
-						break;
-
-					case GTH_METADATA_TYPE_STRING_LIST:
-						string_list = gth_metadata_get_string_list (GTH_METADATA (metadatum));
-						for (scan = gth_string_list_get_list (string_list); scan; scan = scan->next) {
-							char *single_value = (char *) scan->data;
-
-							value->read (single_value);
-							xd.add (xmp_key, value.get());
-						}
-						break;
+					raw_value = gth_metadata_get_raw (GTH_METADATA (metadatum));
+					if ((raw_value != NULL) && (strcmp (raw_value, "") != 0)) {
+						value->read (raw_value);
+						xd.add (xmp_key, value.get());
 					}
 				}
 			}
