@@ -995,8 +995,7 @@ activate_open_with_application_item (GtkMenuItem *menuitem,
 	appinfo = g_object_get_data (G_OBJECT (menuitem), "appinfo");
 	g_return_if_fail (G_IS_APP_INFO (appinfo));
 
-	context = gdk_app_launch_context_new ();
-	gdk_app_launch_context_set_screen (context, gtk_widget_get_screen (GTK_WIDGET (browser)));
+	context = gdk_display_get_app_launch_context (gtk_widget_get_display (GTK_WIDGET (browser)));
 	gdk_app_launch_context_set_timestamp (context, 0);
 	gdk_app_launch_context_set_icon (context, g_app_info_get_icon (appinfo));
 	if (! g_app_info_launch_uris (appinfo, uris, G_APP_LAUNCH_CONTEXT (context), &error)) {
@@ -1083,10 +1082,7 @@ _gth_browser_update_open_menu (GthBrowser *browser,
 		gtk_widget_show (menu_item);
 		gtk_menu_shell_append (GTK_MENU_SHELL (menu), menu_item);
 
-		g_object_set_data_full (G_OBJECT (menu_item),
-					"appinfo",
-					g_object_ref (appinfo),
-					g_object_unref);
+		g_object_set_data (G_OBJECT (menu_item), "appinfo", appinfo);
 		g_signal_connect (menu_item,
 				  "activate",
 				  G_CALLBACK (activate_open_with_application_item),
@@ -1109,7 +1105,7 @@ _gth_browser_update_open_menu (GthBrowser *browser,
 	gtk_widget_show (openwith_item);
 
 	g_hash_table_destroy (used_apps);
-	_g_object_list_unref (appinfo_list);
+	g_list_free (appinfo_list);
 	_g_object_list_unref (file_list);
 	_gtk_tree_path_list_free (items);
 }
@@ -1170,7 +1166,7 @@ fm__gth_browser_file_list_key_press_cb (GthBrowser  *browser,
 	modifiers = gtk_accelerator_get_default_mod_mask ();
 
 	switch (event->keyval) {
-	case GDK_g:
+	case GDK_KEY_g:
 		if ((event->state & modifiers) == 0) {
 			items = gth_file_selection_get_selected (GTH_FILE_SELECTION (gth_browser_get_file_list_view (browser)));
 			file_data_list = gth_file_list_get_files (GTH_FILE_LIST (gth_browser_get_file_list (browser)), items);
@@ -1184,7 +1180,7 @@ fm__gth_browser_file_list_key_press_cb (GthBrowser  *browser,
 		}
 		break;
 
-	case GDK_Delete:
+	case GDK_KEY_Delete:
 		if (((event->state & modifiers) == 0) || ((event->state & modifiers) == GDK_SHIFT_MASK)) {
 			if (gth_browser_get_location_source (browser) != NULL) {
 				items = gth_file_selection_get_selected (GTH_FILE_SELECTION (gth_browser_get_file_list_view (browser)));
