@@ -22,7 +22,6 @@
 #include <config.h>
 #include <gtk/gtk.h>
 #include "dlg-preferences.h"
-#include "gconf-utils.h"
 #include "gth-browser.h"
 #include "gth-enum-types.h"
 #include "gth-file-source-vfs.h"
@@ -41,9 +40,10 @@ typedef struct {
 	GthBrowser *browser;
 	GtkBuilder *builder;
 	GtkWidget  *dialog;
-	GtkWidget  *toolbar_style_combobox;
-	GtkWidget  *thumbnail_size_combobox;
 	GtkWidget  *thumbnail_caption_chooser;
+	GSettings  *general_settings;
+	GSettings  *browser_settings;
+	GSettings  *messages_settings;
 } DialogData;
 
 static int thumb_size[] = { 48, 64, 85, 95, 112, 128, 164, 200, 256 };
@@ -67,15 +67,15 @@ apply_changes (DialogData *data)
 {
 	/* Startup dir. */
 
-	eel_gconf_set_boolean (PREF_GO_TO_LAST_LOCATION, gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (GET_WIDGET ("go_to_last_location_radiobutton"))));
-	eel_gconf_set_boolean (PREF_USE_STARTUP_LOCATION, gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (GET_WIDGET ("use_startup_location_radiobutton"))));
-	eel_gconf_set_boolean (PREF_STORE_METADATA_IN_FILES, gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (GET_WIDGET ("embed_metadata_checkbutton"))));
+	g_settings_set_boolean (data->browser_settings, PREF_BROWSER_GO_TO_LAST_LOCATION, gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (GET_WIDGET ("go_to_last_location_radiobutton"))));
+	g_settings_set_boolean (data->browser_settings, PREF_BROWSER_USE_STARTUP_LOCATION, gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (GET_WIDGET ("use_startup_location_radiobutton"))));
+	g_settings_set_boolean (data->general_settings, PREF_GENERAL_STORE_METADATA_IN_FILES, gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (GET_WIDGET ("embed_metadata_checkbutton"))));
 
-	if (eel_gconf_get_boolean (PREF_USE_STARTUP_LOCATION, FALSE)) {
+	if (g_settings_get_boolean (data->browser_settings, PREF_BROWSER_USE_STARTUP_LOCATION)) {
 		char *location;
 
 		location = gtk_file_chooser_get_uri (GTK_FILE_CHOOSER (GET_WIDGET ("startup_dir_filechooserbutton")));
-		eel_gconf_set_path (PREF_STARTUP_LOCATION, location);
+		_g_settings_set_uri (data->browser_settings, PREF_BROWSER_STARTUP_LOCATION, location);
 		gth_pref_set_startup_location (location);
 		g_free (location);
 	}
@@ -90,6 +90,10 @@ destroy_cb (GtkWidget *widget,
 {
 	apply_changes (data);
 	gth_browser_set_dialog (data->browser, "preferences", NULL);
+
+	g_object_unref (data->general_settings);
+	g_object_unref (data->browser_settings);
+	g_object_unref (data->messages_settings);
 	g_object_unref (data->builder);
 	g_free (data);
 }
@@ -107,7 +111,7 @@ static void
 help_button_clicked_cb (GtkWidget  *widget,
 			DialogData *data)
 {
-	show_help_dialog (GTK_WINDOW (data->dialog), NULL);
+	show_help_dialog (GTK_WINDOW (data->dialog), "preferences");
 }
 
 
@@ -146,7 +150,7 @@ static void
 toolbar_style_changed_cb (GtkWidget  *widget,
 			  DialogData *data)
 {
-	eel_gconf_set_enum (PREF_UI_TOOLBAR_STYLE, GTH_TYPE_TOOLBAR_STYLE, gtk_combo_box_get_active (GTK_COMBO_BOX (data->toolbar_style_combobox)));
+	g_settings_set_enum (data->browser_settings, PREF_BROWSER_TOOLBAR_STYLE, gtk_combo_box_get_active (GTK_COMBO_BOX (GET_WIDGET ("toolbar_style_combobox"))));
 }
 
 
@@ -154,7 +158,23 @@ static void
 thumbnails_pane_orientation_changed_cb (GtkWidget  *widget,
 					DialogData *data)
 {
-	eel_gconf_set_enum (PREF_UI_VIEWER_THUMBNAILS_ORIENT, GTK_TYPE_ORIENTATION, gtk_combo_box_get_active (GTK_COMBO_BOX (GET_WIDGET ("thumbnails_pane_orient_combobox"))));
+	g_settings_set_enum (data->browser_settings, PREF_BROWSER_VIEWER_THUMBNAILS_ORIENT, gtk_combo_box_get_active (GTK_COMBO_BOX (GET_WIDGET ("thumbnails_pane_orient_combobox"))));
+}
+
+
+static void
+file_properties_position_combobox_changed_cb (GtkWidget  *widget,
+					      DialogData *data)
+{
+	g_settings_set_boolean (data->browser_settings, PREF_BROWSER_PROPERTIES_ON_THE_RIGHT, gtk_combo_box_get_active (GTK_COMBO_BOX (GET_WIDGET ("file_properties_position_combobox"))) == 1);
+}
+
+
+static void
+reuse_active_window_checkbutton_toggled_cb (GtkToggleButton *button,
+					    DialogData      *data)
+{
+	g_settings_set_boolean (data->browser_settings, PREF_BROWSER_REUSE_ACTIVE_WINDOW, gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (GET_WIDGET ("reuse_active_window_checkbutton"))));
 }
 
 
@@ -162,7 +182,7 @@ static void
 confirm_deletion_toggled_cb (GtkToggleButton *button,
 			     DialogData      *data)
 {
-	eel_gconf_set_boolean (PREF_MSG_CONFIRM_DELETION, gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (GET_WIDGET ("confirm_deletion_checkbutton"))));
+	g_settings_set_boolean (data->messages_settings, PREF_MSG_CONFIRM_DELETION, gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (GET_WIDGET ("confirm_deletion_checkbutton"))));
 }
 
 
@@ -170,7 +190,7 @@ static void
 ask_to_save_toggled_cb (GtkToggleButton *button,
 			DialogData      *data)
 {
-	eel_gconf_set_boolean (PREF_MSG_SAVE_MODIFIED_IMAGE, gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (GET_WIDGET ("ask_to_save_checkbutton"))));
+	g_settings_set_boolean (data->messages_settings, PREF_MSG_SAVE_MODIFIED_IMAGE, gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (GET_WIDGET ("ask_to_save_checkbutton"))));
 }
 
 
@@ -178,7 +198,7 @@ static void
 thumbnail_size_changed_cb (GtkWidget  *widget,
 			   DialogData *data)
 {
-	eel_gconf_set_integer (PREF_THUMBNAIL_SIZE, thumb_size[gtk_combo_box_get_active (GTK_COMBO_BOX (data->thumbnail_size_combobox))]);
+	g_settings_set_int (data->browser_settings, PREF_BROWSER_THUMBNAIL_SIZE, thumb_size[gtk_combo_box_get_active (GTK_COMBO_BOX (GET_WIDGET ("thumbnail_size_combobox")))]);
 }
 
 
@@ -186,7 +206,7 @@ static void
 fast_file_type_toggled_cb (GtkToggleButton *button,
 			   DialogData      *data)
 {
-	eel_gconf_set_boolean (PREF_FAST_FILE_TYPE, ! gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (GET_WIDGET ("slow_mime_type_checkbutton"))));
+	g_settings_set_boolean (data->browser_settings, PREF_BROWSER_FAST_FILE_TYPE, ! gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (GET_WIDGET ("slow_mime_type_checkbutton"))));
 }
 
 
@@ -197,7 +217,7 @@ thumbnail_caption_chooser_changed_cb (GthMetadataChooser *chooser,
 	char *attributes;
 
 	attributes = gth_metadata_chooser_get_selection (chooser);
-	eel_gconf_set_string (PREF_THUMBNAIL_CAPTION, attributes);
+	g_settings_set_string (data->browser_settings, PREF_BROWSER_THUMBNAIL_CAPTION, attributes);
 
 	g_free (attributes);
 }
@@ -220,38 +240,25 @@ dlg_preferences (GthBrowser *browser)
 	data->browser = browser;
 	data->builder = _gtk_builder_new_from_file ("preferences.ui", NULL);
 	data->dialog = GET_WIDGET ("preferences_dialog");
+	data->general_settings = g_settings_new (GTHUMB_GENERAL_SCHEMA);
+	data->browser_settings = g_settings_new (GTHUMB_BROWSER_SCHEMA);
+	data->messages_settings = g_settings_new (GTHUMB_MESSAGES_SCHEMA);
 
 	gth_browser_set_dialog (browser, "preferences", data->dialog);
 
-	eel_gconf_preload_cache ("/apps/gthumb/browser", GCONF_CLIENT_PRELOAD_ONELEVEL);
-	eel_gconf_preload_cache ("/apps/gthumb/ui", GCONF_CLIENT_PRELOAD_ONELEVEL);
-
-	/* Set widgets data. */
-
-	data->toolbar_style_combobox = _gtk_combo_box_new_with_texts (_("System settings"), _("Text below icons"), _("Text beside icons"), _("Icons only"), _("Text only"), NULL);
-	data->thumbnail_size_combobox = _gtk_combo_box_new_with_texts ("48", "64", "85", "95", "112", "128", "164", "200", "256", NULL);
-
 	/* caption list */
 
 	data->thumbnail_caption_chooser = gth_metadata_chooser_new (GTH_METADATA_ALLOW_IN_FILE_LIST);
 	gtk_widget_show (data->thumbnail_caption_chooser);
 	gtk_container_add (GTK_CONTAINER (GET_WIDGET ("caption_scrolledwindow")), data->thumbnail_caption_chooser);
 
-	current_caption = eel_gconf_get_string (PREF_THUMBNAIL_CAPTION, DEFAULT_THUMBNAIL_CAPTION);
+	current_caption = g_settings_get_string (data->browser_settings, PREF_BROWSER_THUMBNAIL_CAPTION);
 	gth_metadata_chooser_set_selection (GTH_METADATA_CHOOSER (data->thumbnail_caption_chooser), current_caption);
 	g_free (current_caption);
 
-	gtk_widget_show (data->toolbar_style_combobox);
-	gtk_widget_show (data->thumbnail_size_combobox);
-
-	gtk_box_pack_start (GTK_BOX (GET_WIDGET ("toolbar_style_combobox_box")), data->toolbar_style_combobox, FALSE, FALSE, 0);
-	gtk_box_pack_start (GTK_BOX (GET_WIDGET ("thumbnail_size_box")), data->thumbnail_size_combobox, FALSE, FALSE, 0);
-
-	gtk_label_set_mnemonic_widget (GTK_LABEL (GET_WIDGET ("size_label")), data->thumbnail_size_combobox);
-
 	/* * general */
 
-	if (eel_gconf_get_boolean (PREF_USE_STARTUP_LOCATION, FALSE))
+	if (g_settings_get_boolean (data->browser_settings, PREF_BROWSER_USE_STARTUP_LOCATION))
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (GET_WIDGET ("use_startup_location_radiobutton")), TRUE);
 	else
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (GET_WIDGET ("go_to_last_location_radiobutton")), TRUE);
@@ -261,7 +268,7 @@ dlg_preferences (GthBrowser *browser)
 		gtk_widget_set_sensitive (GET_WIDGET ("set_to_current_button"), FALSE);
 	}
 
-	startup_location = eel_gconf_get_path (PREF_STARTUP_LOCATION, NULL);
+	startup_location = _g_settings_get_uri (data->browser_settings, PREF_BROWSER_STARTUP_LOCATION);
 	if (startup_location == NULL)
 		startup_location = g_strdup (get_home_uri ());
 	file_source = gth_main_get_file_source_for_uri (startup_location);
@@ -282,17 +289,28 @@ dlg_preferences (GthBrowser *browser)
 	g_object_unref (file_source);
 	g_free (startup_location);
 
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (GET_WIDGET ("confirm_deletion_checkbutton")), eel_gconf_get_boolean (PREF_MSG_CONFIRM_DELETION, DEFAULT_MSG_CONFIRM_DELETION));
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (GET_WIDGET ("ask_to_save_checkbutton")), eel_gconf_get_boolean (PREF_MSG_SAVE_MODIFIED_IMAGE, DEFAULT_MSG_SAVE_MODIFIED_IMAGE));
-	gtk_combo_box_set_active (GTK_COMBO_BOX (data->toolbar_style_combobox), eel_gconf_get_enum (PREF_UI_TOOLBAR_STYLE, GTH_TYPE_TOOLBAR_STYLE, GTH_TOOLBAR_STYLE_SYSTEM));
-	gtk_combo_box_set_active (GTK_COMBO_BOX (GET_WIDGET ("thumbnails_pane_orient_combobox")), eel_gconf_get_enum (PREF_UI_VIEWER_THUMBNAILS_ORIENT, GTK_TYPE_ORIENTATION, GTK_ORIENTATION_HORIZONTAL));
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (GET_WIDGET ("reuse_active_window_checkbutton")),
+				      g_settings_get_boolean (data->browser_settings, PREF_BROWSER_REUSE_ACTIVE_WINDOW));
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (GET_WIDGET ("confirm_deletion_checkbutton")),
+				      g_settings_get_boolean (data->messages_settings, PREF_MSG_CONFIRM_DELETION));
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (GET_WIDGET ("ask_to_save_checkbutton")),
+				      g_settings_get_boolean (data->messages_settings, PREF_MSG_SAVE_MODIFIED_IMAGE));
+	gtk_combo_box_set_active (GTK_COMBO_BOX (GET_WIDGET ("toolbar_style_combobox")),
+				  g_settings_get_enum (data->browser_settings, PREF_BROWSER_TOOLBAR_STYLE));
+	gtk_combo_box_set_active (GTK_COMBO_BOX (GET_WIDGET ("thumbnails_pane_orient_combobox")),
+				  g_settings_get_enum (data->browser_settings, PREF_BROWSER_VIEWER_THUMBNAILS_ORIENT));
 
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (GET_WIDGET ("embed_metadata_checkbutton")), eel_gconf_get_boolean (PREF_STORE_METADATA_IN_FILES, TRUE));
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (GET_WIDGET ("embed_metadata_checkbutton")),
+				      g_settings_get_boolean (data->general_settings, PREF_GENERAL_STORE_METADATA_IN_FILES));
 
 	/* * browser */
 
-	gtk_combo_box_set_active (GTK_COMBO_BOX (data->thumbnail_size_combobox), get_idx_from_size (eel_gconf_get_integer (PREF_THUMBNAIL_SIZE, DEFAULT_THUMBNAIL_SIZE)));
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (GET_WIDGET ("slow_mime_type_checkbutton")), ! eel_gconf_get_boolean (PREF_FAST_FILE_TYPE, DEFAULT_FAST_FILE_TYPE));
+	gtk_combo_box_set_active (GTK_COMBO_BOX (GET_WIDGET ("thumbnail_size_combobox")),
+				  get_idx_from_size (g_settings_get_int (data->browser_settings, PREF_BROWSER_THUMBNAIL_SIZE)));
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (GET_WIDGET ("slow_mime_type_checkbutton")),
+				      ! g_settings_get_boolean (data->browser_settings, PREF_BROWSER_FAST_FILE_TYPE));
+	gtk_combo_box_set_active (GTK_COMBO_BOX (GET_WIDGET ("file_properties_position_combobox")),
+				  g_settings_get_boolean (data->browser_settings, PREF_BROWSER_PROPERTIES_ON_THE_RIGHT) ? 1 : 0);
 
 	gth_hook_invoke ("dlg-preferences-construct", data->dialog, data->browser, data->builder);
 
@@ -313,7 +331,7 @@ dlg_preferences (GthBrowser *browser)
 
 	/* general */
 
-	g_signal_connect (G_OBJECT (data->toolbar_style_combobox),
+	g_signal_connect (G_OBJECT (GET_WIDGET ("toolbar_style_combobox")),
 			  "changed",
 			  G_CALLBACK (toolbar_style_changed_cb),
 			  data);
@@ -321,6 +339,10 @@ dlg_preferences (GthBrowser *browser)
 			  "changed",
 			  G_CALLBACK (thumbnails_pane_orientation_changed_cb),
 			  data);
+	g_signal_connect (GET_WIDGET ("file_properties_position_combobox"),
+			  "changed",
+			  G_CALLBACK (file_properties_position_combobox_changed_cb),
+			  data);
 	g_signal_connect (G_OBJECT (GET_WIDGET ("use_startup_location_radiobutton")),
 			  "toggled",
 			  G_CALLBACK (use_startup_toggled_cb),
@@ -329,6 +351,10 @@ dlg_preferences (GthBrowser *browser)
 			  "clicked",
 			  G_CALLBACK (set_to_current_cb),
 			  data);
+	g_signal_connect (G_OBJECT (GET_WIDGET ("reuse_active_window_checkbutton")),
+			  "toggled",
+			  G_CALLBACK (reuse_active_window_checkbutton_toggled_cb),
+			  data);
 	g_signal_connect (G_OBJECT (GET_WIDGET ("confirm_deletion_checkbutton")),
 			  "toggled",
 			  G_CALLBACK (confirm_deletion_toggled_cb),
@@ -340,7 +366,7 @@ dlg_preferences (GthBrowser *browser)
 
 	/* browser */
 
-	g_signal_connect (G_OBJECT (data->thumbnail_size_combobox),
+	g_signal_connect (G_OBJECT (GET_WIDGET ("thumbnail_size_combobox")),
 			  "changed",
 			  G_CALLBACK (thumbnail_size_changed_cb),
 			  data);
