@@ -201,7 +201,7 @@ for_each_child_data_free (ForEachChildData *fec)
 		return;
 
 	g_object_unref (fec->base_directory);
-	if (fec->already_visited != NULL)
+	if (fec->already_visited)
 		g_hash_table_destroy (fec->already_visited);
 	clear_child_data (&(fec->current));
 	if (fec->to_visit != NULL) {
@@ -1349,8 +1349,8 @@ copy_file_progress_cb (goffset  current_num_bytes,
 	if (copy_file_data->progress_callback == NULL)
 		return;
 
-	s1 = g_format_size_for_display (copy_file_data->copied_size + current_num_bytes);
-	s2 = g_format_size_for_display (copy_file_data->tot_size);
+	s1 = g_format_size (copy_file_data->copied_size + current_num_bytes);
+	s2 = g_format_size (copy_file_data->tot_size);
 	/* For translators: This is a progress size indicator, for example: 230.4 MB of 512.8 MB */
 	details = g_strdup_printf (_("%s of %s"), s1, s2);
 
