@@ -89,38 +89,13 @@ _g_object_list_unref (GList *list)
 }
 
 
-GType
-g_object_list_get_type (void)
-{
-	static GType type = 0;
-
-	if (type == 0)
-		type = g_boxed_type_register_static ("GObjectList",
-						     (GBoxedCopyFunc) _g_object_list_ref,
-						     (GBoxedFreeFunc) _g_object_list_unref);
-
-	return type;
-}
+typedef GList GObjectList;
 
 
-#if NEED_G_TYPE_ERROR
-
-
-GType
-g_error_get_type (void)
-{
-	static GType type = 0;
-
-	if (type == 0)
-		type = g_boxed_type_register_static ("GError",
-						     (GBoxedCopyFunc) g_error_copy,
-						     (GBoxedFreeFunc) g_error_free);
-
-	return type;
-}
-
-
-#endif
+G_DEFINE_BOXED_TYPE (GObjectList,
+		     g_object_list,
+		     (GBoxedCopyFunc) _g_object_list_ref,
+		     (GBoxedFreeFunc) _g_object_list_unref)
 
 
 GEnumValue *
@@ -550,9 +525,8 @@ _g_time_val_to_exif_date (GTimeVal *time_)
 static int
 _g_time_get_timezone_offset (struct tm *tm)
 {
-	int offset;
+	int offset = 0;
 
-	offset = -timezone;
 #if defined (HAVE_TM_GMTOFF)
 	offset = tm->tm_gmtoff;
 #elif defined (HAVE_TIMEZONE)
@@ -1158,6 +1132,49 @@ _g_strv_find (char       **v,
 }
 
 
+char **
+_g_strv_prepend (char       **str_array,
+                 const char  *str)
+{
+	char **result;
+	int    i;
+	int    j;
+
+	result = g_new (char *, g_strv_length (str_array) + 1);
+	i = 0;
+	result[i++] = g_strdup (str);
+	for (j = 0; str_array[j] != NULL; j++)
+		result[i++] = g_strdup (str_array[j]);
+	result[i] = NULL;
+
+	return result;
+}
+
+
+gboolean
+_g_strv_remove (char       **str_array,
+                const char  *str)
+{
+	int i;
+	int j;
+
+	if (str == NULL)
+		return FALSE;
+
+	for (i = 0; str_array[i] != NULL; i++)
+		if (strcmp (str_array[i], str) == 0)
+			break;
+
+	if (str_array[i] == NULL)
+		return FALSE;
+
+	for (j = i; str_array[j] != NULL; j++)
+		str_array[j] = str_array[j + 1];
+
+	return TRUE;
+}
+
+
 char *
 _g_str_remove_suffix (const char *s,
 		      const char *suffix)
@@ -1473,18 +1490,13 @@ _g_string_list_to_strv (GList *string_list)
 }
 
 
-GType
-g_string_list_get_type (void)
-{
-	static GType type = 0;
+typedef GList GStringList;
 
-	if (type == 0)
-		type = g_boxed_type_register_static ("GStringList",
-						     (GBoxedCopyFunc) _g_string_list_dup,
-						     (GBoxedFreeFunc) _g_string_list_free);
 
-	return type;
-}
+G_DEFINE_BOXED_TYPE (GStringList,
+		     g_string_list,
+		     (GBoxedCopyFunc) _g_string_list_dup,
+		     (GBoxedFreeFunc) _g_string_list_free)
 
 
 GList *
@@ -1911,10 +1923,8 @@ _g_file_get_display_name (GFile *file)
 				       G_FILE_QUERY_INFO_NONE,
 				       NULL,
 				       NULL);
-	if (file_info != NULL) {
+	if (file_info != NULL)
 		name = g_strdup (g_file_info_get_attribute_string (file_info, G_FILE_ATTRIBUTE_STANDARD_DISPLAY_NAME));
-		g_object_unref (file_info);
-	}
 	else
 		name = g_file_get_parse_name (file);
 
@@ -2063,10 +2073,8 @@ _g_file_get_icon (GFile *file)
 				       G_FILE_QUERY_INFO_NONE,
 				       NULL,
 				       NULL);
-	if (file_info != NULL) {
-		icon = (GIcon*) g_object_ref (g_file_info_get_attribute_object (file_info, G_FILE_ATTRIBUTE_STANDARD_ICON));
-		g_object_unref (file_info);
-	}
+	if (file_info != NULL)
+		icon = (GIcon*) g_file_info_get_attribute_object (file_info, G_FILE_ATTRIBUTE_STANDARD_ICON);
 
 	if (icon == NULL)
 		icon = g_themed_icon_new ("file");
@@ -2737,6 +2745,81 @@ _g_mime_type_is_audio (const char *mime_type)
 }
 
 
+char *
+_g_settings_get_uri (GSettings  *settings,
+		     const char *key)
+{
+	char *value;
+	char *uri;
+
+	value = g_settings_get_string (settings, key);
+	if ((value == NULL) || (strcmp (value, "") == 0)) {
+		g_free (value);
+		return NULL;
+	}
+
+	uri = _g_replace (value, "~", g_get_home_dir ());
+	g_free (value);
+
+	return uri;
+}
+
+
+void
+_g_settings_set_uri (GSettings  *settings,
+		     const char *key,
+		     const char *uri)
+{
+	char *value;
+
+	value = _g_replace (uri, g_get_home_dir (), "~");
+	g_settings_set_string (settings, key, value);
+
+	g_free (value);
+}
+
+
+void
+_g_settings_set_string_list (GSettings  *settings,
+			     const char *key,
+			     GList      *list)
+{
+	int     len;
+	char  **strv;
+	int     i;
+	GList  *scan;
+
+	len = g_list_length (list);
+	strv = g_new (char *, len + 1);
+	for (i = 0, scan = list; scan; scan = scan->next)
+		strv[i++] = scan->data;
+	strv[i] = NULL;
+
+	g_settings_set_strv (settings, key, (const char *const *) strv);
+
+	g_free (strv);
+}
+
+
+GList *
+_g_settings_get_string_list (GSettings  *settings,
+			     const char *key)
+{
+	char **strv;
+	int    i;
+	GList *list;
+
+	strv = g_settings_get_strv (settings, key);
+	list = NULL;
+	for (i = 0; strv[i] != NULL; i++)
+		list = g_list_prepend (list, g_strdup (strv[i]));
+
+	g_strfreev (strv);
+
+	return g_list_reverse (list);
+}
+
+
 /* this is totem_time_to_string renamed, thanks to the authors :) */
 char *
 _g_format_duration_for_display (gint64 msecs)
@@ -2769,3 +2852,13 @@ _g_format_duration_for_display (gint64 msecs)
          */
         return g_strdup_printf (C_("short time format", "%d:%02d"), min, sec);
 }
+
+
+GList *
+_g_list_prepend_link (GList *list,
+		      GList *link)
+{
+	link->next = list;
+	if (list != NULL) list->prev = link;
+	return link;
+}
