@@ -32,7 +32,7 @@
 /* -- gth_extension --  */
 
 
-static gpointer gth_extension_parent_class = NULL;
+G_DEFINE_TYPE (GthExtension, gth_extension, G_TYPE_OBJECT)
 
 
 static gboolean
@@ -89,8 +89,6 @@ gth_extension_base_configure (GthExtension *self,
 static void
 gth_extension_class_init (GthExtensionClass *klass)
 {
-	gth_extension_parent_class = g_type_class_peek_parent (klass);
-
 	klass->open = gth_extension_base_open;
 	klass->close = gth_extension_base_close;
 	klass->activate = gth_extension_base_activate;
@@ -101,36 +99,13 @@ gth_extension_class_init (GthExtensionClass *klass)
 
 
 static void
-gth_extension_instance_init (GthExtension *self)
+gth_extension_init (GthExtension *self)
 {
 	self->initialized = FALSE;
 	self->active = FALSE;
 }
 
 
-GType
-gth_extension_get_type (void)
-{
-	static GType gth_extension_type_id = 0;
-	if (gth_extension_type_id == 0) {
-		static const GTypeInfo g_define_type_info = {
-			sizeof (GthExtensionClass),
-			(GBaseInitFunc) NULL,
-			(GBaseFinalizeFunc) NULL,
-			(GClassInitFunc) gth_extension_class_init,
-			(GClassFinalizeFunc) NULL,
-			NULL,
-			sizeof (GthExtension),
-			0,
-			(GInstanceInitFunc) gth_extension_instance_init,
-			NULL
-		};
-		gth_extension_type_id = g_type_register_static (G_TYPE_OBJECT, "GthExtension", &g_define_type_info, 0);
-	}
-	return gth_extension_type_id;
-}
-
-
 gboolean
 gth_extension_open (GthExtension  *self,
 		    GError       **error)
@@ -194,7 +169,7 @@ struct _GthExtensionModulePrivate {
 };
 
 
-static gpointer gth_extension_module_parent_class = NULL;
+G_DEFINE_TYPE (GthExtensionModule, gth_extension_module, GTH_TYPE_EXTENSION)
 
 
 static gboolean
@@ -379,7 +354,6 @@ gth_extension_module_class_init (GthExtensionModuleClass *klass)
 {
 	GthExtensionClass *elc;
 
-	gth_extension_module_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (GthExtensionModulePrivate));
 
 	G_OBJECT_CLASS (klass)->finalize = gth_extension_module_finalize;
@@ -395,35 +369,12 @@ gth_extension_module_class_init (GthExtensionModuleClass *klass)
 
 
 static void
-gth_extension_module_instance_init (GthExtensionModule *self)
+gth_extension_module_init (GthExtensionModule *self)
 {
 	self->priv = G_TYPE_INSTANCE_GET_PRIVATE (self, GTH_TYPE_EXTENSION_MODULE, GthExtensionModulePrivate);
 }
 
 
-GType
-gth_extension_module_get_type (void)
-{
-	static GType gth_extension_module_type_id = 0;
-	if (gth_extension_module_type_id == 0) {
-		static const GTypeInfo g_define_type_info = {
-			sizeof (GthExtensionModuleClass),
-			(GBaseInitFunc) NULL,
-			(GBaseFinalizeFunc) NULL,
-			(GClassInitFunc) gth_extension_module_class_init,
-			(GClassFinalizeFunc) NULL,
-			NULL,
-			sizeof (GthExtensionModule),
-			0,
-			(GInstanceInitFunc) gth_extension_module_instance_init,
-			NULL
-		};
-		gth_extension_module_type_id = g_type_register_static (GTH_TYPE_EXTENSION, "GthExtensionModule", &g_define_type_info, 0);
-	}
-	return gth_extension_module_type_id;
-}
-
-
 GthExtension *
 gth_extension_module_new (const char *module_name)
 {
@@ -445,7 +396,7 @@ struct _GthExtensionDescriptionPrivate {
 };
 
 
-static gpointer gth_extension_description_parent_class = NULL;
+G_DEFINE_TYPE (GthExtensionDescription, gth_extension_description, G_TYPE_OBJECT)
 
 
 static void
@@ -477,15 +428,13 @@ gth_extension_description_finalize (GObject *obj)
 static void
 gth_extension_description_class_init (GthExtensionDescriptionClass *klass)
 {
-	gth_extension_description_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (GthExtensionDescriptionPrivate));
-
 	G_OBJECT_CLASS (klass)->finalize = gth_extension_description_finalize;
 }
 
 
 static void
-gth_extension_description_instance_init (GthExtensionDescription *self)
+gth_extension_description_init (GthExtensionDescription *self)
 {
 	self->priv = G_TYPE_INSTANCE_GET_PRIVATE (self, GTH_TYPE_EXTENSION_DESCRIPTION, GthExtensionDescriptionPrivate);
 	self->priv->opened = FALSE;
@@ -493,29 +442,6 @@ gth_extension_description_instance_init (GthExtensionDescription *self)
 }
 
 
-GType
-gth_extension_description_get_type (void)
-{
-	static GType gth_extension_description_type_id = 0;
-	if (gth_extension_description_type_id == 0) {
-		static const GTypeInfo g_define_type_info = {
-			sizeof (GthExtensionDescriptionClass),
-			(GBaseInitFunc) NULL,
-			(GBaseFinalizeFunc) NULL,
-			(GClassInitFunc) gth_extension_description_class_init,
-			(GClassFinalizeFunc) NULL,
-			NULL,
-			sizeof (GthExtensionDescription),
-			0,
-			(GInstanceInitFunc) gth_extension_description_instance_init,
-			NULL
-		};
-		gth_extension_description_type_id = g_type_register_static (G_TYPE_OBJECT, "GthExtensionDescription", &g_define_type_info, 0);
-	}
-	return gth_extension_description_type_id;
-}
-
-
 static gboolean
 gth_extension_description_load_from_file (GthExtensionDescription *desc,
 					  GFile                   *file)
@@ -526,11 +452,8 @@ gth_extension_description_load_from_file (GthExtensionDescription *desc,
 
 	key_file = g_key_file_new ();
 	file_path = g_file_get_path (file);
-	if (! g_key_file_load_from_file (key_file, file_path, G_KEY_FILE_NONE, NULL)) {
-		g_free (file_path);
-		g_key_file_free (key_file);
+	if (! g_key_file_load_from_file (key_file, file_path, G_KEY_FILE_NONE, NULL))
 		return FALSE;
-	}
 
 	basename = g_file_get_basename (file);
 	desc->id = _g_uri_remove_extension (basename);
@@ -589,14 +512,14 @@ gth_extension_description_get_extension (GthExtensionDescription *desc)
 /* -- gth_extension_manager --  */
 
 
-static gpointer gth_extension_manager_parent_class = NULL;
-
-
 struct _GthExtensionManagerPrivate {
 	GHashTable *extensions;
 };
 
 
+G_DEFINE_TYPE (GthExtensionManager, gth_extension_manager, G_TYPE_OBJECT)
+
+
 static void
 gth_extension_manager_finalize (GObject *obj)
 {
@@ -614,43 +537,19 @@ gth_extension_manager_finalize (GObject *obj)
 static void
 gth_extension_manager_class_init (GthExtensionManagerClass *klass)
 {
-	gth_extension_manager_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (GthExtensionManagerPrivate));
-
 	G_OBJECT_CLASS (klass)->finalize = gth_extension_manager_finalize;
 }
 
 
 static void
-gth_extension_manager_instance_init (GthExtensionManager *self)
+gth_extension_manager_init (GthExtensionManager *self)
 {
 	self->priv = G_TYPE_INSTANCE_GET_PRIVATE (self, GTH_TYPE_EXTENSION_MANAGER, GthExtensionManagerPrivate);
 	self->priv->extensions = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, g_object_unref);
 }
 
 
-GType
-gth_extension_manager_get_type (void) {
-	static GType gth_extension_manager_type_id = 0;
-	if (gth_extension_manager_type_id == 0) {
-		static const GTypeInfo g_define_type_info = {
-			sizeof (GthExtensionManagerClass),
-			(GBaseInitFunc) NULL,
-			(GBaseFinalizeFunc) NULL,
-			(GClassInitFunc) gth_extension_manager_class_init,
-			(GClassFinalizeFunc) NULL,
-			NULL,
-			sizeof (GthExtensionManager),
-			0,
-			(GInstanceInitFunc) gth_extension_manager_instance_init,
-			NULL
-		};
-		gth_extension_manager_type_id = g_type_register_static (G_TYPE_OBJECT, "GthExtensionManager", &g_define_type_info, 0);
-	}
-	return gth_extension_manager_type_id;
-}
-
-
 static void
 gth_extension_manager_load_extensions (GthExtensionManager *self)
 {
@@ -673,6 +572,11 @@ gth_extension_manager_load_extensions (GthExtensionManager *self)
 
 	extensions_dir = g_file_new_for_path (GTHUMB_EXTENSIONS_DIR);
 	enumerator = g_file_enumerate_children (extensions_dir, G_FILE_ATTRIBUTE_STANDARD_NAME, 0, NULL, NULL);
+	if (enumerator == NULL) {
+		g_critical ("Could not find the extensions folder: %s", g_file_get_uri (extensions_dir));
+		abort ();
+	}
+
 	while ((info = g_file_enumerator_next_file (enumerator, NULL, NULL)) != NULL) {
 		const char              *name;
 		GFile                   *ext_file;
@@ -735,7 +639,10 @@ gth_extension_manager_open (GthExtensionManager  *manager,
 	GthExtensionDescription *description;
 
 	description = g_hash_table_lookup (manager->priv->extensions, extension_name);
-	g_return_val_if_fail (description != NULL, FALSE);
+	if (description == NULL) {
+		*error = g_error_new_literal (GTH_ERROR, GTH_ERROR_EXTENSION_DEPENDENCY, "Extension not found");
+		return FALSE;
+	}
 
 	if (description->priv->opened)
 		return TRUE;
@@ -899,50 +806,56 @@ get_extension_optional_dependencies (GthExtensionManager     *manager,
 }
 
 
-GSList *
-gth_extension_manager_order_extensions (GthExtensionManager *manager,
-					GSList              *extensions)
+GList *
+gth_extension_manager_order_extensions (GthExtensionManager  *manager,
+					char                **extensions)
 {
-	GSList *scan;
-	GSList *ordered = NULL;
+	GList *extension_list;
+	int    i;
+	GList *ordered_by_dependency;
+	GList *scan;
 
-	for (scan = extensions; scan; /* void */) {
-		char                    *ext_name = scan->data;
+	extension_list = NULL;
+	for (i = 0; extensions[i] != NULL; i++)
+		if (g_hash_table_lookup (manager->priv->extensions, extensions[i]) != NULL)
+			extension_list = g_list_prepend (extension_list, g_strdup (extensions[i]));
+	extension_list = g_list_reverse (extension_list);
+
+	ordered_by_dependency = NULL;
+	for (scan = extension_list; scan; /* void */) {
+		GList                   *next;
+		char                    *ext_name;
 		GthExtensionDescription *ext_description;
-		GSList                  *next = scan->next;
 		GList                   *dependencies;
-		GSList                  *slink;
-		GList                   *scan_d;
+		GList                   *scan_dep;
 
+		next = extension_list->next;
+		ext_name = extension_list->data;
 		ext_description = g_hash_table_lookup (manager->priv->extensions, ext_name);
-		if (ext_description == NULL) {
-			g_free (scan->data);
-			extensions = g_slist_delete_link (extensions, scan);
-			scan = next;
-			continue;
-		}
+		g_assert (ext_description != NULL);
 
 		dependencies = get_extension_optional_dependencies (manager, ext_description);
-		for (scan_d = dependencies; scan_d; scan_d = scan_d->next) {
-			char *dep_name = scan_d->data;
+		for (scan_dep = dependencies; scan_dep; scan_dep = scan_dep->next) {
+			char  *dep_name = scan_dep->data;
+			GList *link;
 
-			slink = g_slist_find_custom (extensions, dep_name, (GCompareFunc) strcmp);
-			if (slink != NULL) {
-				if (slink == next)
+			link = g_list_find_custom (extension_list, dep_name, (GCompareFunc) strcmp);
+			if (link != NULL) {
+				if (link == next)
 					next = next->next;
 
-				extensions = g_slist_remove_link (extensions, slink);
-				slink->next = ordered;
-				ordered = slink;
+				/* prepend the extension dependency to the ordered list */
+				extension_list = g_list_remove_link (extension_list, link);
+				ordered_by_dependency = _g_list_prepend_link (ordered_by_dependency, link);
 			}
 		}
-		g_list_free (dependencies);
 
-		extensions = g_slist_remove_link (extensions, scan);
-		scan->next = ordered;
-		ordered = scan;
+		/* prepend the extension to the ordered list */
+		extension_list = g_list_remove_link (extension_list, scan);
+		ordered_by_dependency = _g_list_prepend_link (ordered_by_dependency, scan);
+
 		scan = next;
 	}
 
-	return g_slist_reverse (ordered);
+	return g_list_reverse (ordered_by_dependency);
 }
