@@ -23,9 +23,7 @@
 #include <string.h>
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
-#include "gconf-utils.h"
 #include "glib-utils.h"
-#include "gth-cell-renderer-thumbnail.h"
 #include "gth-dumb-notebook.h"
 #include "gth-empty-list.h"
 #include "gth-file-list.h"
@@ -55,8 +53,8 @@ typedef enum {
 	GTH_FILE_LIST_OP_TYPE_SET_FILTER,
 	GTH_FILE_LIST_OP_TYPE_SET_SORT_FUNC,
 	GTH_FILE_LIST_OP_TYPE_ENABLE_THUMBS,
-	GTH_FILE_LIST_OP_TYPE_RENAME_FILE
-	/*GTH_FILE_LIST_OP_TYPE_SET_THUMBS_SIZE,*/
+	GTH_FILE_LIST_OP_TYPE_RENAME_FILE,
+	GTH_FILE_LIST_OP_TYPE_MAKE_FILE_VISIBLE
 } GthFileListOpType;
 
 
@@ -107,6 +105,7 @@ enum {
 
 struct _GthFileListPrivateData
 {
+	GSettings       *settings;
 	GthFileListType  type;
 	GtkAdjustment   *vadj;
 	GtkWidget       *notebook;
@@ -126,10 +125,6 @@ struct _GthFileListPrivateData
 	guint            restart_thumb_update;
 	GList           *queue; /* list of GthFileListOp */
 	GList           *jobs; /* list of ThumbnailJob */
-	GtkCellRenderer *thumbnail_renderer;
-	GtkCellRenderer *text_renderer;
-	GtkCellRenderer *checkbox_renderer;
-	char           **caption_attributes_v;
 	gboolean         cancelling;
 	guint            update_event;
 	gboolean         visibility_changed;
@@ -179,6 +174,9 @@ gth_file_list_op_free (GthFileListOp *op)
 		g_object_unref (op->file);
 		g_object_unref (op->file_data);
 		break;
+	case GTH_FILE_LIST_OP_TYPE_MAKE_FILE_VISIBLE:
+		g_object_unref (op->file);
+		break;
 	default:
 		break;
 	}
@@ -253,7 +251,7 @@ _gth_file_list_queue_op (GthFileList   *file_list,
 /* -- gth_file_list -- */
 
 
-static GtkHBoxClass *parent_class = NULL;
+G_DEFINE_TYPE (GthFileList, gth_file_list, GTK_TYPE_BOX)
 
 
 static void
@@ -269,51 +267,68 @@ gth_file_list_finalize (GObject *object)
 		g_hash_table_unref (file_list->priv->thumb_data);
 		if (file_list->priv->icon_cache != NULL)
 			gth_icon_cache_free (file_list->priv->icon_cache);
-		g_strfreev (file_list->priv->caption_attributes_v);
+		g_object_unref (file_list->priv->settings);
 
 		g_free (file_list->priv);
 		file_list->priv = NULL;
 	}
 
-	G_OBJECT_CLASS (parent_class)->finalize (object);
+	G_OBJECT_CLASS (gth_file_list_parent_class)->finalize (object);
+}
+
+
+static GtkSizeRequestMode
+gth_file_list_get_request_mode (GtkWidget *widget)
+{
+	return GTK_SIZE_REQUEST_CONSTANT_SIZE;
 }
 
 
 static void
-gth_file_list_size_request (GtkWidget      *widget,
-			    GtkRequisition *requisition)
+gth_file_list_get_preferred_width (GtkWidget *widget,
+                		   int       *minimum_width,
+                		   int       *natural_width)
 {
-	GthFileList *file_list;
+	GthFileList *file_list = GTH_FILE_LIST (widget);
+	GtkWidget   *vscrollbar;
+	const int    border = 1;
 
-	GTK_WIDGET_CLASS (parent_class)->size_request (widget, requisition);
+	gtk_widget_get_preferred_width (file_list->priv->view, minimum_width, natural_width);
+	if (minimum_width)
+		*minimum_width += border * 2;
+	if (natural_width)
+		*natural_width += border * 2;
 
-	file_list = GTH_FILE_LIST (widget);
+	vscrollbar = gtk_scrolled_window_get_vscrollbar (GTK_SCROLLED_WINDOW (file_list->priv->scrolled_window));
+	if (gtk_widget_get_visible (vscrollbar) || (file_list->priv->type == GTH_FILE_LIST_TYPE_V_SIDEBAR)) {
+		int vscrollbar_minimum_width;
+		int vscrollbar_natural_width;
+		int scrollbar_spacing;
 
-	if (file_list->priv->type == GTH_FILE_LIST_TYPE_V_SIDEBAR) {
-		int        xthickness;
-		GtkWidget *vscrollbar;
+		gtk_widget_get_preferred_width (vscrollbar, &vscrollbar_minimum_width, &vscrollbar_natural_width);
+		gtk_widget_style_get (file_list->priv->scrolled_window,
+				      "scrollbar-spacing", &scrollbar_spacing,
+				      NULL);
 
-		xthickness = gtk_widget_get_style (file_list->priv->scrolled_window)->xthickness;
-		requisition->width = file_list->priv->thumb_size + (THUMBNAIL_BORDER * 2) + xthickness * 2;
-
-		vscrollbar = gtk_scrolled_window_get_vscrollbar (GTK_SCROLLED_WINDOW (file_list->priv->scrolled_window));
-		if (gtk_widget_get_visible (vscrollbar)) {
-			GtkRequisition vscrollbar_requisition;
-			int            scrollbar_spacing;
-
-			gtk_widget_size_request (vscrollbar, &vscrollbar_requisition);
-			gtk_widget_style_get (file_list->priv->scrolled_window,
-					      "scrollbar-spacing", &scrollbar_spacing,
-					      NULL);
-			requisition->width += vscrollbar_requisition.width + scrollbar_spacing;
-		}
+		*minimum_width += vscrollbar_minimum_width + scrollbar_spacing;
+		*natural_width += vscrollbar_natural_width + scrollbar_spacing;
 	}
-	else if (file_list->priv->type == GTH_FILE_LIST_TYPE_H_SIDEBAR) {
-		int ythickness;
+}
 
-		ythickness = gtk_widget_get_style (file_list->priv->scrolled_window)->ythickness;
-		requisition->height = file_list->priv->thumb_size + (THUMBNAIL_BORDER * 2) + ythickness * 2;
-	}
+
+static void
+gth_file_list_get_preferred_height (GtkWidget *widget,
+                		    int       *minimum_height,
+                		    int       *natural_height)
+{
+	GthFileList *file_list = GTH_FILE_LIST (widget);
+	const int    border = 1;
+
+	gtk_widget_get_preferred_height (file_list->priv->view, minimum_height, natural_height);
+	if (minimum_height)
+		*minimum_height += border * 2;
+	if (natural_height)
+		*natural_height += border * 2;
 }
 
 
@@ -323,13 +338,13 @@ gth_file_list_class_init (GthFileListClass *class)
 	GObjectClass   *object_class;
 	GtkWidgetClass *widget_class;
 
-	parent_class = g_type_class_peek_parent (class);
-
 	object_class = (GObjectClass*) class;
 	object_class->finalize = gth_file_list_finalize;
 
 	widget_class = (GtkWidgetClass*) class;
-	widget_class->size_request = gth_file_list_size_request;
+	widget_class->get_request_mode = gth_file_list_get_request_mode;
+	widget_class->get_preferred_width = gth_file_list_get_preferred_width;
+	widget_class->get_preferred_height = gth_file_list_get_preferred_height;
 }
 
 
@@ -374,11 +389,11 @@ static void
 gth_file_list_init (GthFileList *file_list)
 {
 	file_list->priv = g_new0 (GthFileListPrivateData, 1);
+	file_list->priv->settings = g_settings_new (GTHUMB_BROWSER_SCHEMA);
 	file_list->priv->thumb_data = g_hash_table_new_full (g_file_hash, (GEqualFunc) g_file_equal, g_object_unref, (GDestroyNotify) thumb_data_unref);
-	file_list->priv->thumb_size = DEFAULT_THUMBNAIL_SIZE;
+	file_list->priv->thumb_size = g_settings_get_int (file_list->priv->settings, PREF_BROWSER_THUMBNAIL_SIZE);
 	file_list->priv->ignore_hidden_thumbs = FALSE;
 	file_list->priv->load_thumbs = TRUE;
-	file_list->priv->caption_attributes_v = g_strsplit ("none", ",", -1);
 	file_list->priv->cancelling = FALSE;
 	file_list->priv->update_event = 0;
 	file_list->priv->visibles = NULL;
@@ -506,72 +521,25 @@ file_view_drag_data_get_cb (GtkWidget        *widget,
 }
 
 
-static void
-checkbox_toggled_cb (GtkCellRendererToggle *cell_renderer,
-                     char                  *path,
-                     gpointer               user_data)
-{
-	GthFileList  *file_list = user_data;
-	GtkTreePath  *tpath;
-	GthFileStore *file_store;
-	GtkTreeIter   iter;
-
-	tpath = gtk_tree_path_new_from_string (path);
-	if (tpath == NULL)
-		return;
-
-	file_store = (GthFileStore*) gth_file_view_get_model (GTH_FILE_VIEW (file_list->priv->view));
-	if (gtk_tree_model_get_iter (GTK_TREE_MODEL (file_store), &iter, tpath)) {
-		gboolean checked;
-
-		gtk_tree_model_get (GTK_TREE_MODEL (file_store), &iter,
-				    GTH_FILE_STORE_CHECKED_COLUMN, &checked,
-				    -1);
-		gth_file_store_set (file_store,
-				    &iter,
-				    GTH_FILE_STORE_CHECKED_COLUMN, ! checked,
-				    -1);
-	}
-
-	gtk_tree_path_free (tpath);
-}
-
-
 static void
 _gth_file_list_update_orientation (GthFileList *file_list)
 {
-	if (file_list->priv->type == GTH_FILE_LIST_TYPE_V_SIDEBAR)
+	GtkPolicyType hscrollbar_policy;
+	GtkPolicyType vscrollbar_policy;
+
+	hscrollbar_policy = GTK_POLICY_AUTOMATIC;
+	vscrollbar_policy = GTK_POLICY_AUTOMATIC;
+
+	if (file_list->priv->type == GTH_FILE_LIST_TYPE_V_SIDEBAR) {
 		gtk_orientable_set_orientation (GTK_ORIENTABLE (file_list), GTK_ORIENTATION_VERTICAL);
+		vscrollbar_policy = GTK_POLICY_ALWAYS;
+	}
 	else if (file_list->priv->type == GTH_FILE_LIST_TYPE_H_SIDEBAR)
 		gtk_orientable_set_orientation (GTK_ORIENTABLE (file_list), GTK_ORIENTATION_HORIZONTAL);
-}
 
-
-static void
-_gth_file_list_set_type (GthFileList     *file_list,
-		 	 GthFileListType  list_type)
-{
-	file_list->priv->type = list_type;
-
-	if ((file_list->priv->type == GTH_FILE_LIST_TYPE_SELECTOR) || (file_list->priv->type == GTH_FILE_LIST_TYPE_NO_SELECTION))
-		gth_file_selection_set_selection_mode (GTH_FILE_SELECTION (file_list->priv->view), GTK_SELECTION_NONE);
-	else if ((file_list->priv->type == GTH_FILE_LIST_TYPE_H_SIDEBAR) || (file_list->priv->type == GTH_FILE_LIST_TYPE_V_SIDEBAR))
-		gth_file_selection_set_selection_mode (GTH_FILE_SELECTION (file_list->priv->view), GTK_SELECTION_SINGLE);
-	else
-		gth_file_selection_set_selection_mode (GTH_FILE_SELECTION (file_list->priv->view), GTK_SELECTION_MULTIPLE);
-
-	g_object_set (file_list->priv->checkbox_renderer,
-		      "visible", ((file_list->priv->type == GTH_FILE_LIST_TYPE_BROWSER) || (file_list->priv->type == GTH_FILE_LIST_TYPE_SELECTOR)),
-		      NULL);
-
-	/* use the fixed size for horizontal sidebars to view a single row at
-	 * a time. */
-
-	g_object_set (file_list->priv->thumbnail_renderer,
-		      "fixed_size", TRUE /* (file_list->priv->type == GTH_FILE_LIST_TYPE_H_SIDEBAR) */,
-		      NULL);
-
-	_gth_file_list_update_orientation (file_list);
+	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (file_list->priv->scrolled_window),
+					hscrollbar_policy,
+					vscrollbar_policy);
 }
 
 
@@ -601,10 +569,7 @@ gth_file_list_construct (GthFileList     *file_list,
 			 GthFileListType  list_type,
 			 gboolean         enable_drag_drop)
 {
-	GtkWidget       *viewport;
-	GtkCellRenderer *renderer;
-	GthFileStore    *model;
-	GtkCellLayout   *cell_layout;
+	GthFileStore *model;
 
 	file_list->priv->thumb_loader = gth_thumb_loader_new (file_list->priv->thumb_size);
 	file_list->priv->icon_cache = gth_icon_cache_new (gtk_icon_theme_get_for_screen (gtk_widget_get_screen (GTK_WIDGET (file_list))), file_list->priv->thumb_size / 2);
@@ -615,20 +580,12 @@ gth_file_list_construct (GthFileList     *file_list,
 
 	/* the message pane */
 
-	viewport = gtk_viewport_new (NULL, NULL);
-	gtk_viewport_set_shadow_type (GTK_VIEWPORT (viewport),
-				      GTK_SHADOW_ETCHED_IN);
-
 	file_list->priv->message = gth_empty_list_new (_(EMPTY));
 
 	/* the file view */
 
 	file_list->priv->scrolled_window = gtk_scrolled_window_new (NULL, NULL);
-	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (file_list->priv->scrolled_window),
-					GTK_POLICY_NEVER,
-					GTK_POLICY_AUTOMATIC);
-	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (file_list->priv->scrolled_window),
-					     GTK_SHADOW_ETCHED_IN);
+	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (file_list->priv->scrolled_window), GTK_SHADOW_ETCHED_IN);
 
 	file_list->priv->vadj = gtk_scrolled_window_get_vadjustment (GTK_SCROLLED_WINDOW (file_list->priv->scrolled_window));
 	g_signal_connect (G_OBJECT (file_list->priv->vadj),
@@ -678,66 +635,7 @@ gth_file_list_construct (GthFileList     *file_list,
 				  file_list);
 	}
 
-	/* checkbox */
-
-	file_list->priv->checkbox_renderer = renderer = gtk_cell_renderer_toggle_new ();
-	g_signal_connect (file_list->priv->checkbox_renderer,
-			  "toggled",
-			  G_CALLBACK (checkbox_toggled_cb),
-			  file_list);
-
-	cell_layout = gth_file_view_add_renderer (GTH_FILE_VIEW (file_list->priv->view),
-						  GTH_FILE_VIEW_RENDERER_CHECKBOX,
-						  file_list->priv->checkbox_renderer);
-	gtk_cell_layout_set_attributes (cell_layout,
-					renderer,
-					"active", GTH_FILE_STORE_CHECKED_COLUMN,
-					NULL);
-
-	/* thumbnail */
-
-	file_list->priv->thumbnail_renderer = renderer = gth_cell_renderer_thumbnail_new ();
-
-	cell_layout = gth_file_view_add_renderer (GTH_FILE_VIEW (file_list->priv->view),
-						  GTH_FILE_VIEW_RENDERER_THUMBNAIL,
-						  file_list->priv->thumbnail_renderer);
-	gtk_cell_layout_set_attributes (cell_layout,
-					renderer,
-					"thumbnail", GTH_FILE_STORE_THUMBNAIL_COLUMN,
-					"is_icon", GTH_FILE_STORE_IS_ICON_COLUMN,
-					"file", GTH_FILE_STORE_FILE_DATA_COLUMN,
-					NULL);
-	if (file_list->priv->type == GTH_FILE_LIST_TYPE_BROWSER)
-		gtk_cell_layout_add_attribute (cell_layout,
-					       renderer,
-					       "selected",
-					       GTH_FILE_STORE_CHECKED_COLUMN);
-	else if (file_list->priv->type == GTH_FILE_LIST_TYPE_SELECTOR)
-		gtk_cell_layout_add_attribute (cell_layout,
-					       renderer,
-					       "checked",
-					       GTH_FILE_STORE_CHECKED_COLUMN);
-
-	/* text */
-
-	file_list->priv->text_renderer = renderer = gtk_cell_renderer_text_new ();
-
-	cell_layout = gth_file_view_add_renderer (GTH_FILE_VIEW (file_list->priv->view),
-						  GTH_FILE_VIEW_RENDERER_TEXT,
-						  file_list->priv->text_renderer);
-	gtk_cell_layout_set_attributes (cell_layout,
-					renderer,
-					"text", GTH_FILE_STORE_METADATA_COLUMN,
-					"visible", GTH_FILE_STORE_METADATA_VISIBLE_COLUMN,
-					NULL);
-
-	gth_file_view_update_attributes (GTH_FILE_VIEW (file_list->priv->view),
-					 file_list->priv->checkbox_renderer,
-					 file_list->priv->thumbnail_renderer,
-					 file_list->priv->text_renderer,
-					 file_list->priv->thumb_size);
-
-	_gth_file_list_set_type (file_list, list_type);
+	gth_file_list_set_type (file_list, list_type);
 
 	/* pack the widgets together */
 
@@ -748,10 +646,7 @@ gth_file_list_construct (GthFileList     *file_list,
 	gtk_container_add (GTK_CONTAINER (file_list->priv->notebook), file_list->priv->scrolled_window);
 
 	gtk_widget_show (file_list->priv->message);
-	gtk_container_add (GTK_CONTAINER (viewport), file_list->priv->message);
-
-	gtk_widget_show (viewport);
-	gtk_container_add (GTK_CONTAINER (file_list->priv->notebook), viewport);
+	gtk_container_add (GTK_CONTAINER (file_list->priv->notebook), file_list->priv->message);
 
 	gtk_widget_show (file_list->priv->notebook);
 	gtk_box_pack_start (GTK_BOX (file_list), file_list->priv->notebook, TRUE, TRUE, 0);
@@ -760,35 +655,7 @@ gth_file_list_construct (GthFileList     *file_list,
 }
 
 
-GType
-gth_file_list_get_type (void)
-{
-	static GType type = 0;
-
-	if (! type) {
-		GTypeInfo type_info = {
-			sizeof (GthFileListClass),
-			NULL,
-			NULL,
-			(GClassInitFunc) gth_file_list_class_init,
-			NULL,
-			NULL,
-			sizeof (GthFileList),
-			0,
-			(GInstanceInitFunc) gth_file_list_init
-		};
-
-		type = g_type_register_static (GTK_TYPE_VBOX,
-					       "GthFileList",
-					       &type_info,
-					       0);
-	}
-
-	return type;
-}
-
-
-GtkWidget*
+GtkWidget *
 gth_file_list_new (GtkWidget       *file_view,
 		   GthFileListType  list_type,
 		   gboolean         enable_drag_drop)
@@ -806,7 +673,18 @@ void
 gth_file_list_set_type (GthFileList     *file_list,
 			GthFileListType  list_type)
 {
-	_gth_file_list_set_type (file_list, list_type);
+	g_return_if_fail (GTH_IS_FILE_LIST (file_list));
+
+	file_list->priv->type = list_type;
+
+	if ((file_list->priv->type == GTH_FILE_LIST_TYPE_SELECTOR) || (file_list->priv->type == GTH_FILE_LIST_TYPE_NO_SELECTION))
+		gth_file_selection_set_selection_mode (GTH_FILE_SELECTION (file_list->priv->view), GTK_SELECTION_NONE);
+	else if ((file_list->priv->type == GTH_FILE_LIST_TYPE_H_SIDEBAR) || (file_list->priv->type == GTH_FILE_LIST_TYPE_V_SIDEBAR))
+		gth_file_selection_set_selection_mode (GTH_FILE_SELECTION (file_list->priv->view), GTK_SELECTION_SINGLE);
+	else
+		gth_file_selection_set_selection_mode (GTH_FILE_SELECTION (file_list->priv->view), GTK_SELECTION_MULTIPLE);
+
+	_gth_file_list_update_orientation (file_list);
 }
 
 
@@ -945,46 +823,6 @@ _gth_file_list_update_pane (GthFileList *file_list)
 }
 
 
-#define MAX_TEXT_LENGTH 70
-
-
-static GString *
-_gth_file_list_get_metadata (GthFileList *file_list,
-			     GthFileData *file_data)
-{
-	GString *metadata;
-	int      i;
-
-	metadata = g_string_new (NULL);
-	for (i = 0; file_list->priv->caption_attributes_v[i] != NULL; i++) {
-		char *value;
-
-		value = gth_file_data_get_attribute_as_string (file_data, file_list->priv->caption_attributes_v[i]);
-		if (value != NULL) {
-			if (metadata->len > 0)
-				g_string_append (metadata, "\n");
-			if (gth_file_view_truncate_metadata (GTH_FILE_VIEW (file_list->priv->view))
-			    && g_utf8_strlen (value, -1) > MAX_TEXT_LENGTH)
-			{
-				char *tmp;
-
-				tmp = g_strdup (value);
-				g_utf8_strncpy (tmp, value, MAX_TEXT_LENGTH);
-				g_free (value);
-				value = g_strdup_printf ("%s […]", tmp);
-
-				g_free (tmp);
-			}
-			g_string_append (metadata, value);
-		}
-
-		g_free (value);
-	}
-
-	return metadata;
-}
-
-
 static void
 gfl_add_files (GthFileList *file_list,
 	       GList       *files,
@@ -994,6 +832,8 @@ gfl_add_files (GthFileList *file_list,
 	GList        *scan;
 	char         *cache_base_uri;
 
+	performance (DEBUG_INFO, "gfl_add_files start");
+
 	file_store = (GthFileStore*) gth_file_view_get_model (GTH_FILE_VIEW (file_list->priv->view));
 
 	cache_base_uri = g_strconcat (get_home_uri (), "/.thumbnails", NULL);
@@ -1003,7 +843,6 @@ gfl_add_files (GthFileList *file_list,
 		ThumbData   *thumb_data;
 		GIcon       *icon;
 		GdkPixbuf   *pixbuf = NULL;
-		GString     *metadata;
 
 		if (g_file_info_get_file_type (file_data->info) != G_FILE_TYPE_REGULAR)
 			continue;
@@ -1024,24 +863,21 @@ gfl_add_files (GthFileList *file_list,
 
 		icon = g_file_info_get_icon (file_data->info);
 		pixbuf = gth_icon_cache_get_pixbuf (file_list->priv->icon_cache, icon);
-		metadata = _gth_file_list_get_metadata (file_list, file_data);
 		gth_file_store_queue_add (file_store,
 					  file_data,
 					  pixbuf,
-					  TRUE,
-					  metadata->str,
 					  TRUE);
 
-		g_string_free (metadata, TRUE);
 		if (pixbuf != NULL)
 			g_object_unref (pixbuf);
-
 		g_free (uri);
 	}
 	g_free (cache_base_uri);
 
 	gth_file_store_exec_add (file_store, position);
 	_gth_file_list_update_pane (file_list);
+
+	performance (DEBUG_INFO, "gfl_add_files end");
 }
 
 
@@ -1118,18 +954,11 @@ gfl_update_files (GthFileList *file_list,
 		thumb_data->thumb_loaded = FALSE;
 		thumb_data->thumb_created = FALSE;
 
-		if (gth_file_store_find (file_store, file_data->file, &iter)) {
-			GString *metadata;
-
-			metadata = _gth_file_list_get_metadata (file_list, file_data);
+		if (gth_file_store_find (file_store, file_data->file, &iter))
 			gth_file_store_queue_set (file_store,
 						  &iter,
 						  GTH_FILE_STORE_FILE_DATA_COLUMN, file_data,
-						  GTH_FILE_STORE_METADATA_COLUMN, metadata->str,
 						  -1);
-
-			g_string_free (metadata, TRUE);
-		}
 	}
 	gth_file_store_exec_set (file_store);
 	_gth_file_list_update_pane (file_list);
@@ -1159,7 +988,6 @@ gfl_rename_file (GthFileList *file_list,
 	file_store = (GthFileStore*) gth_file_view_get_model (GTH_FILE_VIEW (file_list->priv->view));
 	if (gth_file_store_find (file_store, file, &iter)) {
 		ThumbData *thumb_data;
-		GString   *metadata;
 
 		thumb_data = g_hash_table_lookup (file_list->priv->thumb_data, file);
 		g_assert (thumb_data != NULL);
@@ -1169,14 +997,10 @@ gfl_rename_file (GthFileList *file_list,
 				     thumb_data_ref (thumb_data));
 		g_hash_table_remove (file_list->priv->thumb_data, file);
 
-		metadata = _gth_file_list_get_metadata (file_list, file_data);
 		gth_file_store_set (file_store,
 				    &iter,
 				    GTH_FILE_STORE_FILE_DATA_COLUMN, file_data,
-				    GTH_FILE_STORE_METADATA_COLUMN, metadata->str,
 				    -1);
-
-		g_string_free (metadata, TRUE);
 	}
 	_gth_file_list_update_pane (file_list);
 }
@@ -1200,8 +1024,8 @@ static void
 gfl_set_files (GthFileList *file_list,
 	       GList       *files)
 {
-	gth_thumb_loader_set_save_thumbnails (file_list->priv->thumb_loader, eel_gconf_get_boolean (PREF_SAVE_THUMBNAILS, TRUE));
-	gth_thumb_loader_set_max_file_size (file_list->priv->thumb_loader, eel_gconf_get_integer (PREF_THUMBNAIL_LIMIT, 0));
+	gth_thumb_loader_set_save_thumbnails (file_list->priv->thumb_loader, g_settings_get_boolean (file_list->priv->settings, PREF_BROWSER_SAVE_THUMBNAILS));
+	gth_thumb_loader_set_max_file_size (file_list->priv->thumb_loader, g_settings_get_int (file_list->priv->settings, PREF_BROWSER_THUMBNAIL_LIMIT));
 	gth_file_selection_unselect_all (GTH_FILE_SELECTION (file_list->priv->view));
 
 	gth_file_store_clear ((GthFileStore*) gth_file_view_get_model (GTH_FILE_VIEW (file_list->priv->view)));
@@ -1316,8 +1140,10 @@ gfl_enable_thumbs (GthFileList *file_list,
 	GthFileStore *file_store;
 	GtkTreeIter   iter;
 
-	gth_thumb_loader_set_save_thumbnails (file_list->priv->thumb_loader, eel_gconf_get_boolean (PREF_SAVE_THUMBNAILS, TRUE));
-	gth_thumb_loader_set_max_file_size (file_list->priv->thumb_loader, eel_gconf_get_integer (PREF_THUMBNAIL_LIMIT, 0));
+	gth_thumb_loader_set_save_thumbnails (file_list->priv->thumb_loader,
+					      g_settings_get_boolean (file_list->priv->settings, PREF_BROWSER_SAVE_THUMBNAILS));
+	gth_thumb_loader_set_max_file_size (file_list->priv->thumb_loader,
+					    g_settings_get_int (file_list->priv->settings, PREF_BROWSER_THUMBNAIL_LIMIT));
 
 	file_list->priv->load_thumbs = enable;
 
@@ -1381,17 +1207,13 @@ gth_file_list_set_thumb_size (GthFileList *file_list,
 	file_list->priv->thumb_size = size;
 
 	gth_thumb_loader_set_requested_size (file_list->priv->thumb_loader, size);
-	gth_thumb_loader_set_save_thumbnails (file_list->priv->thumb_loader, eel_gconf_get_boolean (PREF_SAVE_THUMBNAILS, TRUE));
-	gth_thumb_loader_set_max_file_size (file_list->priv->thumb_loader, eel_gconf_get_integer (PREF_THUMBNAIL_LIMIT, 0));
+	gth_thumb_loader_set_save_thumbnails (file_list->priv->thumb_loader,  g_settings_get_boolean (file_list->priv->settings, PREF_BROWSER_SAVE_THUMBNAILS));
+	gth_thumb_loader_set_max_file_size (file_list->priv->thumb_loader, g_settings_get_int (file_list->priv->settings, PREF_BROWSER_THUMBNAIL_LIMIT));
 
 	gth_icon_cache_free (file_list->priv->icon_cache);
 	file_list->priv->icon_cache = gth_icon_cache_new (gtk_icon_theme_get_for_screen (gtk_widget_get_screen (GTK_WIDGET (file_list))), size / 2);
 
-	gth_file_view_update_attributes (GTH_FILE_VIEW (file_list->priv->view),
-					 file_list->priv->checkbox_renderer,
-					 file_list->priv->thumbnail_renderer,
-					 file_list->priv->text_renderer,
-					 file_list->priv->thumb_size);
+	gth_file_view_set_thumbnail_size (GTH_FILE_VIEW (file_list->priv->view), file_list->priv->thumb_size);
 
 	_gth_file_list_update_orientation (file_list);
 }
@@ -1401,41 +1223,36 @@ void
 gth_file_list_set_caption (GthFileList *file_list,
 			   const char  *attributes)
 {
-	GthFileStore *file_store;
-	GtkTreeIter   iter;
-	gboolean      metadata_visible;
+	gth_file_view_set_caption (GTH_FILE_VIEW (file_list->priv->view), attributes);
+}
 
-	g_strfreev (file_list->priv->caption_attributes_v);
-	file_list->priv->caption_attributes_v = g_strsplit (attributes, ",", -1);
 
-	metadata_visible = (strcmp (file_list->priv->caption_attributes_v[0], "none") != 0);
-	g_object_set (file_list->priv->text_renderer,
-		      "visible", metadata_visible,
-		      "height", metadata_visible ? -1 : 0,
-		      NULL);
+static void
+gfl_make_file_visible (GthFileList *file_list,
+		       GFile       *file)
+{
+	int pos;
 
-	file_store = (GthFileStore *) gth_file_view_get_model (GTH_FILE_VIEW (file_list->priv->view));
-	if (gth_file_store_get_first (file_store, &iter)) {
-		do {
-			GthFileData *file_data;
-			GString     *metadata;
-
-			file_data = gth_file_store_get_file (file_store, &iter);
-			metadata = _gth_file_list_get_metadata (file_list, file_data);
-			gth_file_store_queue_set (file_store,
-						  &iter,
-						  GTH_FILE_STORE_METADATA_COLUMN, metadata->str,
-						  -1);
-
-			g_string_free (metadata, TRUE);
-		}
-		while (gth_file_store_get_next (file_store, &iter));
-
-		gth_file_store_exec_set (file_store);
+	pos = gth_file_store_get_pos ((GthFileStore *) gth_file_view_get_model (GTH_FILE_VIEW (file_list->priv->view)), file);
+	if (pos >= 0) {
+		gth_file_selection_select (GTH_FILE_SELECTION (file_list->priv->view), pos);
+		gth_file_view_set_cursor (GTH_FILE_VIEW (file_list->priv->view), pos);
 	}
 }
 
 
+void
+gth_file_list_make_file_visible (GthFileList *file_list,
+				 GFile       *file)
+{
+	GthFileListOp *op;
+
+	op = gth_file_list_op_new (GTH_FILE_LIST_OP_TYPE_MAKE_FILE_VISIBLE);
+	op->file = g_object_ref (file);
+	_gth_file_list_queue_op (file_list, op);
+}
+
+
 GtkWidget *
 gth_file_list_get_view (GthFileList *file_list)
 {
@@ -1593,7 +1410,6 @@ thumbnail_job_ready_cb (GObject      *source_object,
 	if ((! success && g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED))
 	    || file_list->priv->cancelling)
 	{
-		_g_object_unref (pixbuf);
 		thumbnail_job_free (job);
 		return;
 	}
@@ -1972,6 +1788,9 @@ _gth_file_list_exec_next_op (GthFileList *file_list)
 	case GTH_FILE_LIST_OP_TYPE_RENAME_FILE:
 		gfl_rename_file (file_list, op->file, op->file_data);
 		break;
+	case GTH_FILE_LIST_OP_TYPE_MAKE_FILE_VISIBLE:
+		gfl_make_file_visible (file_list, op->file);
+		break;
 	default:
 		exec_next_op = FALSE;
 		break;
@@ -2120,4 +1939,3 @@ gth_file_list_prev_file (GthFileList *file_list,
 
 	return (scan != NULL) ? pos : -1;
 }
-
