@@ -23,7 +23,6 @@
 #include <string.h>
 #include <glib/gi18n.h>
 #include <glib.h>
-#include "gconf-utils.h"
 #include "gth-file-data.h"
 #include "gio-utils.h"
 #include "glib-utils.h"
@@ -53,12 +52,14 @@ struct _GthFileSourceVfsPrivate
 };
 
 
-static GthFileSourceClass *parent_class = NULL;
 static guint mount_changed_event_id = 0;
 static guint mount_added_event_id = 0;
 static guint mount_removed_event_id = 0;
 
 
+G_DEFINE_TYPE (GthFileSourceVfs, gth_file_source_vfs, GTH_TYPE_FILE_SOURCE)
+
+
 static GList *
 gth_file_source_vfs_add_special_dir (GList         *list, 
 				     GthFileSource *file_source,
@@ -221,6 +222,8 @@ fec__done_func (GError   *error,
 {
 	GthFileSourceVfs *file_source_vfs = user_data;
 
+	performance (DEBUG_INFO, "gth_file_source_vfs_for_each_child end");
+
 	gth_file_source_set_active (GTH_FILE_SOURCE (file_source_vfs), FALSE);
 	file_source_vfs->priv->ready_func (G_OBJECT (file_source_vfs),
 					   error,
@@ -297,6 +300,8 @@ gth_file_source_vfs_for_each_child (GthFileSource        *file_source,
 	g_cancellable_reset (gth_file_source_get_cancellable (file_source));
 	g_hash_table_remove_all (file_source_vfs->priv->hidden_files);
 
+	performance (DEBUG_INFO, "gth_file_source_vfs_for_each_child start");
+
 	file_source_vfs->priv->start_dir_func = start_dir_func;
 	file_source_vfs->priv->for_each_file_func = for_each_file_func;
 	file_source_vfs->priv->ready_func = ready_func;
@@ -778,7 +783,10 @@ void
 gth_file_mananger_trash_files (GtkWindow *window,
 			       GList     *file_list /* GthFileData list */)
 {
-	if (eel_gconf_get_boolean (PREF_MSG_CONFIRM_DELETION, DEFAULT_MSG_CONFIRM_DELETION)) {
+	GSettings *settings;
+
+	settings = g_settings_new (GTHUMB_MESSAGES_SCHEMA);
+	if (g_settings_get_boolean (settings, PREF_MSG_CONFIRM_DELETION)) {
 		int        file_count;
 		char      *prompt;
 		GtkWidget *d;
@@ -786,7 +794,8 @@ gth_file_mananger_trash_files (GtkWindow *window,
 		file_count = g_list_length (file_list);
 		if (file_count == 1) {
 			GthFileData *file_data = file_list->data;
-			prompt = g_strdup_printf (_("Are you sure you want to move \"%s\" to trash?"), g_file_info_get_display_name (file_data->info));
+			prompt = g_strdup_printf (_("Are you sure you want to move \"%s\" to trash?"),
+						  g_file_info_get_display_name (file_data->info));
 		}
 		else
 			prompt = g_strdup_printf (ngettext("Are you sure you want to move to trash "
@@ -812,6 +821,8 @@ gth_file_mananger_trash_files (GtkWindow *window,
 	}
 	else
 		trash_files (window, file_list);
+
+	g_object_unref (settings);
 }
 
 
@@ -891,7 +902,7 @@ gth_file_source_vfs_finalize (GObject *object)
 		file_source_vfs->priv = NULL;
 	}
 
-	G_OBJECT_CLASS (parent_class)->finalize (object);
+	G_OBJECT_CLASS (gth_file_source_vfs_parent_class)->finalize (object);
 }
 
 
@@ -901,11 +912,10 @@ gth_file_source_vfs_class_init (GthFileSourceVfsClass *class)
 	GObjectClass       *object_class;
 	GthFileSourceClass *file_source_class;
 
-	parent_class = g_type_class_peek_parent (class);
 	object_class = (GObjectClass*) class;
-	file_source_class = (GthFileSourceClass*) class;
-
 	object_class->finalize = gth_file_source_vfs_finalize;
+
+	file_source_class = (GthFileSourceClass*) class;
 	file_source_class->get_entry_points = gth_file_source_vfs_get_entry_points;
 	file_source_class->to_gio_file = gth_file_source_vfs_to_gio_file;
 	file_source_class->get_file_info = gth_file_source_vfs_get_file_info;
@@ -930,31 +940,3 @@ gth_file_source_vfs_init (GthFileSourceVfs *file_source)
 	for (i = 0; i < GTH_MONITOR_N_EVENTS; i++)
 		file_source->priv->monitor_queue[i] = NULL;
 }
-
-
-GType
-gth_file_source_vfs_get_type (void)
-{
-	static GType type = 0;
-
-	if (! type) {
-		GTypeInfo type_info = {
-			sizeof (GthFileSourceVfsClass),
-			NULL,
-			NULL,
-			(GClassInitFunc) gth_file_source_vfs_class_init,
-			NULL,
-			NULL,
-			sizeof (GthFileSourceVfs),
-			0,
-			(GInstanceInitFunc) gth_file_source_vfs_init
-		};
-
-		type = g_type_register_static (GTH_TYPE_FILE_SOURCE,
-					       "GthFileSourceVfs",
-					       &type_info,
-					       0);
-	}
-
-	return type;
-}
