@@ -23,6 +23,7 @@
 #include <glib/gi18n.h>
 #include "glib-utils.h"
 #include "gth-file-store.h"
+#include "gth-marshal.h"
 
 
 #undef  DEBUG_FILE_STORE
@@ -31,8 +32,8 @@
 
 
 enum {
-	CHECK_CHANGED,
 	VISIBILITY_CHANGED,
+	THUMBNAIL_CHANGED,
 	LAST_SIGNAL
 };
 
@@ -42,19 +43,18 @@ static guint gth_file_store_signals[LAST_SIGNAL] = { 0 };
 
 
 typedef struct {
+	int          ref_count;
+
 	GthFileData *file_data;
 	GdkPixbuf   *thumbnail;
-	gboolean     is_icon;
-	char        *metadata;
-	gboolean     checked;
+	gboolean     is_icon : 1;
 
 	/*< private >*/
 
-	guint        ref_count;
 	guint        pos;
 	guint        abs_pos;
-	gboolean     visible;
-	gboolean     changed;
+	gboolean     visible : 1;
+	gboolean     changed : 1;
 } GthFileRow;
 
 
@@ -70,13 +70,22 @@ struct _GthFileStorePrivate
 	GthTest             *filter;
 	GList               *queue;
 	GthFileDataCompFunc  cmp_func;
-	gboolean             inverse_sort;
-	gboolean             update_filter;
-	gboolean             check_changed;
+	gboolean             inverse_sort : 1;
+	gboolean             update_filter : 1;
 };
 
 
-static GObjectClass *parent_class = NULL;
+static void gtk_tree_model_interface_init (GtkTreeModelIface *iface);
+static void gtk_tree_drag_source_interface_init (GtkTreeDragSourceIface *iface);
+
+
+G_DEFINE_TYPE_WITH_CODE (GthFileStore,
+			 gth_file_store,
+			 G_TYPE_OBJECT,
+			 G_IMPLEMENT_INTERFACE (GTK_TYPE_TREE_MODEL,
+					        gtk_tree_model_interface_init)
+		         G_IMPLEMENT_INTERFACE (GTK_TYPE_TREE_DRAG_SOURCE,
+		        		 	gtk_tree_drag_source_interface_init))
 
 
 static GthFileRow *
@@ -117,21 +126,6 @@ _gth_file_row_set_thumbnail (GthFileRow *row,
 }
 
 
-static void
-_gth_file_row_set_metadata (GthFileRow *row,
-			    const char *metadata)
-{
-	if (metadata == NULL)
-		return;
-
-	if (metadata == row->metadata)
-		return;
-
-	g_free (row->metadata);
-	row->metadata = g_strdup (metadata);
-}
-
-
 GthFileRow *
 _gth_file_row_copy (GthFileRow *row)
 {
@@ -140,9 +134,7 @@ _gth_file_row_copy (GthFileRow *row)
 	row2 = _gth_file_row_new ();
 	_gth_file_row_set_file (row2, row->file_data);
 	_gth_file_row_set_thumbnail (row2, row->thumbnail);
-	_gth_file_row_set_metadata (row2, row->metadata);
 	row2->is_icon = row->is_icon;
-	row2->checked = row->checked;
 	row2->pos = row->pos;
 	row2->abs_pos = row->abs_pos;
 	row2->visible = row->visible;
@@ -152,11 +144,11 @@ _gth_file_row_copy (GthFileRow *row)
 }
 
 
-static GthFileRow *
+G_GNUC_UNUSED
+static void
 _gth_file_row_ref (GthFileRow *row)
 {
 	row->ref_count++;
-	return row;
 }
 
 
@@ -170,7 +162,6 @@ _gth_file_row_unref (GthFileRow *row)
 		g_object_unref (row->file_data);
 	if (row->thumbnail != NULL)
 		g_object_unref (row->thumbnail);
-	g_free (row->metadata);
 	g_free (row);
 }
 
@@ -178,7 +169,6 @@ _gth_file_row_unref (GthFileRow *row)
 static void
 _gth_file_store_clear_queue (GthFileStore *file_store)
 {
-	g_list_foreach (file_store->priv->queue, (GFunc) _gth_file_row_unref, NULL);
 	g_list_free (file_store->priv->queue);
 	file_store->priv->queue = NULL;
 }
@@ -212,67 +202,67 @@ gth_file_store_finalize (GObject *object)
 
 	file_store = GTH_FILE_STORE (object);
 
-	if (file_store->priv != NULL) {
-		_gth_file_store_free_rows (file_store);
-		if (file_store->priv->filter != NULL)
-			g_object_unref (file_store->priv->filter);
-		g_free (file_store->priv);
-		file_store->priv = NULL;
-	}
+	_gth_file_store_free_rows (file_store);
+	_g_object_unref (file_store->priv->filter);
 
-	G_OBJECT_CLASS (parent_class)->finalize (object);
+	G_OBJECT_CLASS (gth_file_store_parent_class)->finalize (object);
 }
 
 
 static void
-gth_file_store_class_init (GthFileStoreClass *class)
+gth_file_store_class_init (GthFileStoreClass *klass)
 {
 	GObjectClass *object_class;
 
-	parent_class = g_type_class_peek_parent (class);
+	g_type_class_add_private (klass, sizeof (GthFileStorePrivate));
 
-	object_class = (GObjectClass*) class;
+	object_class = (GObjectClass*) klass;
 	object_class->finalize = gth_file_store_finalize;
 
-	gth_file_store_signals[CHECK_CHANGED] =
-		g_signal_new ("check_changed",
-			      G_TYPE_FROM_CLASS (class),
-			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (GthFileStoreClass, check_changed),
-			      NULL, NULL,
-			      g_cclosure_marshal_VOID__VOID,
-			      G_TYPE_NONE,
-			      0);
 	gth_file_store_signals[VISIBILITY_CHANGED] =
 		g_signal_new ("visibility_changed",
-			      G_TYPE_FROM_CLASS (class),
+			      G_TYPE_FROM_CLASS (klass),
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (GthFileStoreClass, visibility_changed),
 			      NULL, NULL,
 			      g_cclosure_marshal_VOID__VOID,
 			      G_TYPE_NONE,
 			      0);
+	gth_file_store_signals[THUMBNAIL_CHANGED] =
+			g_signal_new ("thumbnail-changed",
+				      G_TYPE_FROM_CLASS (klass),
+				      G_SIGNAL_RUN_LAST,
+				      G_STRUCT_OFFSET (GthFileStoreClass, thumbnail_changed),
+				      NULL, NULL,
+				      gth_marshal_VOID__BOXED_BOXED,
+				      G_TYPE_NONE,
+				      2,
+				      GTK_TYPE_TREE_PATH,
+				      GTK_TYPE_TREE_ITER);
 }
 
 
 static void
 gth_file_store_init (GthFileStore *file_store)
 {
-	file_store->priv = g_new0 (GthFileStorePrivate, 1);
+	file_store->priv = G_TYPE_INSTANCE_GET_PRIVATE (file_store, GTH_TYPE_FILE_STORE, GthFileStorePrivate);
+	file_store->priv->all_rows = NULL;
 	file_store->priv->rows = NULL;
 	file_store->priv->size = 0;
+	file_store->priv->tot_rows = 0;
 	file_store->priv->num_rows = 0;
 	file_store->priv->stamp = g_random_int ();
+	file_store->priv->load_thumbs = FALSE;
 	file_store->priv->filter = gth_test_new ();
+	file_store->priv->queue = NULL;
+	file_store->priv->cmp_func = NULL;
+	file_store->priv->inverse_sort = FALSE;
+	file_store->priv->update_filter = FALSE;
 
 	if (column_type[0] == G_TYPE_INVALID) {
 		column_type[GTH_FILE_STORE_FILE_DATA_COLUMN] = GTH_TYPE_FILE_DATA;
 		column_type[GTH_FILE_STORE_THUMBNAIL_COLUMN] = GDK_TYPE_PIXBUF;
 		column_type[GTH_FILE_STORE_IS_ICON_COLUMN] = G_TYPE_BOOLEAN;
-		column_type[GTH_FILE_STORE_FILENAME_COLUMN] = G_TYPE_STRING;
-		column_type[GTH_FILE_STORE_METADATA_COLUMN] = G_TYPE_STRING;
-		column_type[GTH_FILE_STORE_METADATA_VISIBLE_COLUMN] = G_TYPE_BOOLEAN;
-		column_type[GTH_FILE_STORE_CHECKED_COLUMN] = G_TYPE_BOOLEAN;
 	}
 }
 
@@ -280,7 +270,7 @@ gth_file_store_init (GthFileStore *file_store)
 static GtkTreeModelFlags
 gth_file_store_get_flags (GtkTreeModel *tree_model)
 {
-	return GTK_TREE_MODEL_LIST_ONLY /*| GTK_TREE_MODEL_ITERS_PERSIST*/;
+	return GTK_TREE_MODEL_LIST_ONLY;
 }
 
 
@@ -384,22 +374,6 @@ gth_file_store_get_value (GtkTreeModel *tree_model,
 		g_value_init (value, G_TYPE_BOOLEAN);
 		g_value_set_boolean (value, row->is_icon);
 		break;
-	case GTH_FILE_STORE_FILENAME_COLUMN:
-		g_value_init (value, G_TYPE_STRING);
-		g_value_set_string (value, g_file_info_get_display_name (row->file_data->info));
-		break;
-	case GTH_FILE_STORE_METADATA_COLUMN:
-		g_value_init (value, G_TYPE_STRING);
-		g_value_set_string (value, row->metadata);
-		break;
-	case GTH_FILE_STORE_METADATA_VISIBLE_COLUMN:
-		g_value_init (value, G_TYPE_BOOLEAN);
-		g_value_set_boolean (value, (row->metadata != NULL) && ! g_str_equal (row->metadata, ""));
-		break;
-	case GTH_FILE_STORE_CHECKED_COLUMN:
-		g_value_init (value, G_TYPE_BOOLEAN);
-		g_value_set_boolean (value, row->checked);
-		break;
 	}
 }
 
@@ -429,6 +403,31 @@ gth_file_store_iter_next (GtkTreeModel  *tree_model,
 }
 
 
+static gboolean
+gth_file_store_iter_previous (GtkTreeModel *tree_model,
+			      GtkTreeIter  *iter)
+{
+	GthFileStore *file_store;
+	GthFileRow   *row;
+
+	if ((iter == NULL) || (iter->user_data == NULL))
+		return FALSE;
+
+	file_store = (GthFileStore *) tree_model;
+
+	g_return_val_if_fail (VALID_ITER (iter, file_store), FALSE);
+
+	row = (GthFileRow*) iter->user_data;
+	if (row->pos == 0)
+		return FALSE;
+
+	iter->stamp = file_store->priv->stamp;
+	iter->user_data = file_store->priv->rows[row->pos - 1];
+
+	return TRUE;
+}
+
+
 static gboolean
 gth_file_store_iter_children (GtkTreeModel *tree_model,
 			      GtkTreeIter  *iter,
@@ -594,7 +593,7 @@ gth_file_store_drag_data_delete (GtkTreeDragSource *drag_source,
 
 
 static void
-gtk_tree_model_iface_init (GtkTreeModelIface *iface)
+gtk_tree_model_interface_init (GtkTreeModelIface *iface)
 {
 	iface->get_flags       = gth_file_store_get_flags;
 	iface->get_n_columns   = gth_file_store_get_n_columns;
@@ -603,6 +602,7 @@ gtk_tree_model_iface_init (GtkTreeModelIface *iface)
 	iface->get_path        = gth_file_store_get_path;
 	iface->get_value       = gth_file_store_get_value;
 	iface->iter_next       = gth_file_store_iter_next;
+	iface->iter_previous   = gth_file_store_iter_previous;
 	iface->iter_children   = gth_file_store_iter_children;
 	iface->iter_has_child  = gth_file_store_iter_has_child;
 	iface->iter_n_children = gth_file_store_iter_n_children;
@@ -612,7 +612,7 @@ gtk_tree_model_iface_init (GtkTreeModelIface *iface)
 
 
 static void
-gtk_tree_drag_source_iface_init (GtkTreeDragSourceIface *iface)
+gtk_tree_drag_source_interface_init (GtkTreeDragSourceIface *iface)
 {
 	iface->row_draggable = gth_file_store_row_draggable;
 	iface->drag_data_get = gth_file_store_drag_data_get;
@@ -620,43 +620,6 @@ gtk_tree_drag_source_iface_init (GtkTreeDragSourceIface *iface)
 }
 
 
-GType
-gth_file_store_get_type (void)
-{
-	static GType type = 0;
-
-	if (! type) {
-		GTypeInfo type_info = {
-			sizeof (GthFileStoreClass),
-			NULL,
-			NULL,
-			(GClassInitFunc) gth_file_store_class_init,
-			NULL,
-			NULL,
-			sizeof (GthFileStore),
-			0,
-			(GInstanceInitFunc) gth_file_store_init
-		};
-		static const GInterfaceInfo gtk_tree_model_info = {
-			(GInterfaceInitFunc) gtk_tree_model_iface_init,
-			NULL,
-			NULL
-		};
-		static const GInterfaceInfo gtk_tree_drag_source_info = {
-			(GInterfaceInitFunc) gtk_tree_drag_source_iface_init,
-			NULL,
-			NULL
-		};
-
-		type = g_type_register_static (G_TYPE_OBJECT, "GthFileStore", &type_info, 0);
-		g_type_add_interface_static (type, GTK_TYPE_TREE_MODEL, &gtk_tree_model_info);
-		g_type_add_interface_static (type, GTK_TYPE_TREE_DRAG_SOURCE, &gtk_tree_drag_source_info);
-	}
-
-	return type;
-}
-
-
 GthFileStore *
 gth_file_store_new (void)
 {
@@ -700,23 +663,6 @@ _gth_file_store_get_files (GthFileStore *file_store)
 }
 
 
-static void
-_gth_file_store_row_changed (GthFileStore *file_store,
-			     GthFileRow   *row)
-{
-	GtkTreePath *path;
-	GtkTreeIter  iter;
-
-	path = gtk_tree_path_new ();
-	gtk_tree_path_append_index (path, row->pos);
-	gth_file_store_get_iter (GTK_TREE_MODEL (file_store), &iter, path);
-
-	gtk_tree_model_row_changed (GTK_TREE_MODEL (file_store), path, &iter);
-
-	gtk_tree_path_free (path);
-}
-
-
 static int
 campare_row_func (gconstpointer a,
 		  gconstpointer b,
@@ -829,10 +775,12 @@ _gth_file_store_update_visibility (GthFileStore *file_store,
 	guint        new_rows_n = 0;
 	int          i;
 	GList       *files;
+	GHashTable  *files_index;
 	GList       *scan;
 	GthFileData *file;
 	int          j, k;
 	gboolean     row_deleted;
+	GHashTable  *new_rows_index;
 
 
 #ifdef DEBUG_FILE_STORE
@@ -855,7 +803,7 @@ g_print ("UPDATE VISIBILITY\n");
 	for (i = 0; i < position; i++)
 		all_rows[j++] = _gth_file_row_copy (file_store->priv->all_rows[i]);
 	for (scan = add_queue; scan; scan = scan->next)
-		all_rows[j++] = _gth_file_row_ref ((GthFileRow *) scan->data);
+		all_rows[j++] = (GthFileRow *) scan->data;
 	for (i = position; i < file_store->priv->tot_rows; i++)
 		all_rows[j++] = _gth_file_row_copy (file_store->priv->all_rows[i]);
 
@@ -873,11 +821,18 @@ g_print ("UPDATE VISIBILITY\n");
 
 	_gth_file_store_sort (file_store, all_rows, all_rows_n);
 
+	/* store the new_rows file positions in an hash table for
+	 * faster searching. */
+	files_index = g_hash_table_new (g_direct_hash, g_direct_equal);
 	files = NULL;
 	for (i = 0; i < all_rows_n; i++) {
 		GthFileRow *row = all_rows[i];
 
 		row->abs_pos = i;
+		/* store i + 1 instead of i to distinguish when a file is
+		 * present and when the file is in the first position.
+		 * (g_hash_table_lookup returns NULL if the file is not present) */
+		g_hash_table_insert (files_index, row->file_data, GINT_TO_POINTER (i + 1));
 		files = g_list_prepend (files, g_object_ref (row->file_data));
 	}
 	files = g_list_reverse (files);
@@ -885,21 +840,16 @@ g_print ("UPDATE VISIBILITY\n");
 	new_rows_n = 0;
 	gth_test_set_file_list (file_store->priv->filter, files);
 	while ((file = gth_test_get_next (file_store->priv->filter)) != NULL) {
-		GthFileRow *row = NULL;
+		i = GPOINTER_TO_INT (g_hash_table_lookup (files_index, file));
+		g_assert (i != 0);
+		i--; /* in files_index (i + 1) was stored, see above. */
 
-		for (i = 0; i < all_rows_n; i++) {
-			row = all_rows[i];
-			if (row->file_data == file)
-				break;
-		}
-
-		g_assert (i < all_rows_n);
-
-		row->visible = TRUE;
+		all_rows[i]->visible = TRUE;
 		new_rows_n++;
 	}
 
 	_g_object_list_unref (files);
+	g_hash_table_unref (files_index);
 
 	/* create the new visible rows array */
 
@@ -918,15 +868,18 @@ g_print ("UPDATE VISIBILITY\n");
 
 	/* hide filtered out files */
 
+	/* store the new_rows file positions in an hash table for
+	 * faster searching. */
+	new_rows_index = g_hash_table_new (g_direct_hash, g_direct_equal);
+	for (j = 0; j < new_rows_n; j++)
+		g_hash_table_insert (new_rows_index, new_rows[j]->file_data, GINT_TO_POINTER (j + 1));
+
 	row_deleted = FALSE;
 	for (i = old_rows_n - 1; i >= 0; i--) {
 		/* search old_rows[i] in new_rows */
 
-		for (j = 0; j < new_rows_n; j++)
-			if (old_rows[i]->file_data == new_rows[j]->file_data)
-				break;
-
-		if (j < new_rows_n)
+		j = GPOINTER_TO_INT (g_hash_table_lookup (new_rows_index, old_rows[i]->file_data));
+		if (j > 0)
 			continue;
 
 		/* old_rows[i] is not present in new_rows, emit a deleted
@@ -942,6 +895,8 @@ g_print ("  DELETE: %d\n", old_rows[i]->pos);
 		row_deleted = TRUE;
 	}
 
+	g_hash_table_unref (new_rows_index);
+
 	/* compact the old visible rows array if needed */
 
 	if (row_deleted) {
@@ -960,21 +915,26 @@ g_print ("  DELETE: %d\n", old_rows[i]->pos);
 	 * Reorder the two arrays according to the new_rows order */
 
 	if (old_rows_n > 0) {
+		GHashTable *old_rows_index;
 		gboolean    order_changed;
 		int        *new_order;
 		GthFileRow *tmp_row;
 
+		/* store the old_rows file positions in an hash table for
+		 * faster searching. */
+		old_rows_index = g_hash_table_new (g_direct_hash, g_direct_equal);
+		for (j = 0; j < old_rows_n; j++)
+			g_hash_table_insert (old_rows_index, old_rows[j]->file_data, GINT_TO_POINTER (j + 1));
+
 		order_changed = FALSE;
 		new_order = g_new0 (int, old_rows_n);
 		for (i = 0, k = 0; i < new_rows_n; i++) {
 			/* search new_rows[i] in old_rows */
 
-			for (j = 0; j < old_rows_n; j++)
-				if (new_rows[i]->file_data == old_rows[j]->file_data)
-					break;
-
-			if (j >= old_rows_n)
+			j = GPOINTER_TO_INT (g_hash_table_lookup (old_rows_index, new_rows[i]->file_data));
+			if (j == 0)
 				continue;
+			j--; /* in old_rows_index we stored j+1, decrement to get the real position */
 
 			/* old_rows[j] == new_rows[i] */
 
@@ -1018,6 +978,7 @@ g_print ("\n");
 		}
 
 		g_free (new_order);
+		g_hash_table_unref (old_rows_index);
 	}
 
 	/* set the new state */
@@ -1074,7 +1035,6 @@ g_print ("  INSERT: %d\n", i);
 	}
 
 	g_signal_emit (file_store, gth_file_store_signals[VISIBILITY_CHANGED], 0);
-	g_signal_emit (file_store, gth_file_store_signals[CHECK_CHANGED], 0);
 
 	g_free (new_rows);
 	g_free (old_rows);
@@ -1184,40 +1144,6 @@ gth_file_store_n_visibles (GthFileStore *file_store)
 }
 
 
-GList *
-gth_file_store_get_checked (GthFileStore *file_store)
-{
-	GList *list = NULL;
-	int    i;
-
-	for (i = 0; i < file_store->priv->num_rows; i++) {
-		GthFileRow *row = file_store->priv->rows[i];
-
-		if ((row != NULL) && row->checked)
-			list = g_list_prepend (list, g_object_ref (file_store->priv->rows[i]->file_data));
-	}
-
-	return g_list_reverse (list);
-}
-
-
-int
-gth_file_store_get_n_checked (GthFileStore *file_store)
-{
-	int n = 0;
-	int i;
-
-	for (i = 0; i < file_store->priv->num_rows; i++) {
-		GthFileRow *row = file_store->priv->rows[i];
-
-		if ((row != NULL) && row->checked)
-			n++;
-	}
-
-	return n;
-}
-
-
 GthFileData *
 gth_file_store_get_file (GthFileStore *file_store,
 			 GtkTreeIter  *iter)
@@ -1421,11 +1347,9 @@ gth_file_store_add (GthFileStore *file_store,
 		    GthFileData  *file,
 		    GdkPixbuf    *thumbnail,
 		    gboolean      is_icon,
-		    const char   *metadata,
-		    gboolean      checked,
 		    int           position)
 {
-	gth_file_store_queue_add (file_store, file, thumbnail, is_icon, metadata, checked);
+	gth_file_store_queue_add (file_store, file, thumbnail, is_icon);
 	gth_file_store_exec_add (file_store, position);
 }
 
@@ -1434,9 +1358,7 @@ void
 gth_file_store_queue_add (GthFileStore *file_store,
 			  GthFileData  *file,
 			  GdkPixbuf    *thumbnail,
-			  gboolean      is_icon,
-			  const char   *metadata,
-			  gboolean      checked)
+			  gboolean      is_icon)
 {
 	GthFileRow *row;
 
@@ -1445,9 +1367,7 @@ gth_file_store_queue_add (GthFileStore *file_store,
 	row = _gth_file_row_new ();
 	_gth_file_row_set_file (row, file);
 	_gth_file_row_set_thumbnail (row, thumbnail);
-	_gth_file_row_set_metadata (row, metadata);
 	row->is_icon = is_icon;
-	row->checked = checked;
 
 	file_store->priv->queue = g_list_prepend (file_store->priv->queue, row);
 }
@@ -1474,11 +1394,10 @@ gth_file_store_queue_set_valist (GthFileStore *file_store,
 
   	row = (GthFileRow*) iter->user_data;
 
-  	column = va_arg (var_args, int);
+ 	column = va_arg (var_args, int);
   	while (column != -1) {
   		GthFileData *file_data;
   		GdkPixbuf   *thumbnail;
-  		const char  *metadata;
 
   		switch (column) {
   		case GTH_FILE_STORE_FILE_DATA_COLUMN:
@@ -1498,18 +1417,6 @@ gth_file_store_queue_set_valist (GthFileStore *file_store,
   			row->is_icon = va_arg (var_args, gboolean);
   			row->changed = TRUE;
   			break;
-  		case GTH_FILE_STORE_METADATA_COLUMN:
-  			metadata = va_arg (var_args, const char *);
-  			_gth_file_row_set_metadata (row, metadata);
-  			row->changed = TRUE;
-  			break;
-  		case GTH_FILE_STORE_METADATA_VISIBLE_COLUMN:
-  			break;
-  		case GTH_FILE_STORE_CHECKED_COLUMN:
-  			row->checked = va_arg (var_args, gboolean);
-  			row->changed = TRUE;
-  			file_store->priv->check_changed = TRUE;
-  			break;
   		default:
   			g_warning ("%s: Invalid column number %d added to iter (remember to end your list of columns with a -1)", G_STRLOC, column);
   			break;
@@ -1548,6 +1455,25 @@ gth_file_store_queue_set (GthFileStore *file_store,
 }
 
 
+static void
+_gth_file_store_row_changed (GthFileStore *file_store,
+			     GthFileRow   *row)
+{
+	GtkTreePath *path;
+	GtkTreeIter  iter;
+
+	path = gtk_tree_path_new ();
+	gtk_tree_path_append_index (path, row->pos);
+
+	iter.stamp = file_store->priv->stamp;
+	iter.user_data = row;
+
+	gtk_tree_model_row_changed (GTK_TREE_MODEL (file_store), path, &iter);
+
+	gtk_tree_path_free (path);
+}
+
+
 static void
 _gth_file_store_list_changed (GthFileStore *file_store)
 {
@@ -1563,19 +1489,60 @@ _gth_file_store_list_changed (GthFileStore *file_store)
 }
 
 
+static void
+_gth_file_store_thumbnail_changed (GthFileStore *file_store,
+				   GthFileRow   *row)
+{
+	GtkTreePath *path;
+	GtkTreeIter  iter;
+
+	path = gtk_tree_path_new ();
+	gtk_tree_path_append_index (path, row->pos);
+
+	iter.stamp = file_store->priv->stamp;
+	iter.user_data = row;
+
+	g_signal_emit (file_store, gth_file_store_signals[THUMBNAIL_CHANGED], 0, path, &iter);
+
+	gtk_tree_path_free (path);
+}
+
+
+static void
+_gth_file_store_thumbnails_changed (GthFileStore *file_store)
+{
+	int i;
+
+	for (i = 0; i < file_store->priv->num_rows; i++) {
+		GthFileRow *row = file_store->priv->rows[i];
+
+		if (row->visible && row->changed)
+			_gth_file_store_thumbnail_changed (file_store, row);
+		row->changed = FALSE;
+	}
+}
+
+
 void
 gth_file_store_exec_set (GthFileStore *file_store)
 {
-	_gth_file_store_list_changed (file_store);
+	/* This is an speed optimization.  When the thumbnails are updated in
+	 * the store the visibility doesn't need to be updated, so we avoid to
+	 * emit the 'row-changed' signal for each row, which causes the
+	 * GtkIconView to invalidate the size of all the items, and instead
+	 * emit a single 'thumbnail-changed' signal that can be used to just
+	 * redraw the GthFileView. */
+	if (file_store->priv->update_filter)
+		_gth_file_store_list_changed (file_store);
+	else
+		_gth_file_store_thumbnails_changed (file_store);
+
 	_gth_file_store_clear_queue (file_store);
+
 	if (file_store->priv->update_filter) {
 		_gth_file_store_update_visibility (file_store, NULL, -1);
 		file_store->priv->update_filter = FALSE;
 	}
-	else if (file_store->priv->check_changed) {
-		g_signal_emit (file_store, gth_file_store_signals[CHECK_CHANGED], 0);
-		file_store->priv->check_changed = FALSE;
-	}
 }
 
 
@@ -1598,7 +1565,7 @@ gth_file_store_queue_remove (GthFileStore *file_store,
 
   	row = (GthFileRow*) iter->user_data;
 
-	file_store->priv->queue = g_list_prepend (file_store->priv->queue, _gth_file_row_ref (file_store->priv->all_rows[row->abs_pos]));
+	file_store->priv->queue = g_list_prepend (file_store->priv->queue, file_store->priv->all_rows[row->abs_pos]);
 }
 
 
