@@ -59,7 +59,17 @@ struct _GthFilterPrivate {
 };
 
 
-static gpointer parent_class = NULL;
+static void gth_filter_dom_domizable_interface_init (DomDomizableInterface *iface);
+static void gth_filter_gth_duplicable_interface_init (GthDuplicableInterface *iface);
+
+
+G_DEFINE_TYPE_WITH_CODE (GthFilter,
+			 gth_filter,
+			 GTH_TYPE_TEST,
+			 G_IMPLEMENT_INTERFACE (DOM_TYPE_DOMIZABLE,
+					 	gth_filter_dom_domizable_interface_init)
+		         G_IMPLEMENT_INTERFACE (GTH_TYPE_DUPLICABLE,
+		        		 	gth_filter_gth_duplicable_interface_init))
 
 
 static DomElement*
@@ -127,8 +137,6 @@ gth_filter_real_load_from_element (DomDomizable *base,
 			test = gth_test_chain_new (GTH_MATCH_TYPE_NONE, NULL);
 			dom_domizable_load_from_element (DOM_DOMIZABLE (test), node);
 			gth_filter_set_test (self, GTH_TEST_CHAIN (test));
-
-			g_object_unref (test);
 		}
 		else if (g_strcmp0 (node->tag_name, "limit") == 0) {
 			gth_filter_set_limit (self,
@@ -172,7 +180,7 @@ gth_filter_set_file_list (GthTest *test,
 {
 	GthFilter *filter = GTH_FILTER (test);
 
-	GTH_TEST_CLASS (parent_class)->set_file_list (test, files);
+	GTH_TEST_CLASS (gth_filter_parent_class)->set_file_list (test, files);
 
 	if ((filter->priv->limit_type != GTH_LIMIT_TYPE_NONE)
 	    && (filter->priv->sort_name != NULL)
@@ -253,7 +261,7 @@ create_control_for_files (GthFilter *filter)
 	GtkWidget *label;
 	char      *value;
 
-	control = gtk_hbox_new (FALSE, 6);
+	control = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
 
 	/* limit label */
 
@@ -325,7 +333,7 @@ create_control_for_size (GthFilter *filter)
 	int        i, size_idx;
 	gboolean   size_set = FALSE;
 
-	control = gtk_hbox_new (FALSE, 6);
+	control = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
 
 	/* limit label */
 
@@ -435,7 +443,7 @@ gth_filter_finalize (GObject *object)
 
 	_g_object_unref (filter->priv->test);
 
-	G_OBJECT_CLASS (parent_class)->finalize (object);
+	G_OBJECT_CLASS (gth_filter_parent_class)->finalize (object);
 }
 
 
@@ -445,7 +453,6 @@ gth_filter_class_init (GthFilterClass *klass)
 	GObjectClass *object_class;
 	GthTestClass *test_class;
 
-	parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (GthFilterPrivate));
 
 	object_class = G_OBJECT_CLASS (klass);
@@ -460,7 +467,7 @@ gth_filter_class_init (GthFilterClass *klass)
 
 
 static void
-gth_filter_dom_domizable_interface_init (DomDomizableIface *iface)
+gth_filter_dom_domizable_interface_init (DomDomizableInterface *iface)
 {
 	iface->create_element = gth_filter_real_create_element;
 	iface->load_from_element = gth_filter_real_load_from_element;
@@ -468,7 +475,7 @@ gth_filter_dom_domizable_interface_init (DomDomizableIface *iface)
 
 
 static void
-gth_filter_gth_duplicable_interface_init (GthDuplicableIface *iface)
+gth_filter_gth_duplicable_interface_init (GthDuplicableInterface *iface)
 {
 	iface->duplicate = gth_filter_real_duplicate;
 }
@@ -486,46 +493,6 @@ gth_filter_init (GthFilter *filter)
 }
 
 
-GType
-gth_filter_get_type (void)
-{
-        static GType type = 0;
-
-        if (! type) {
-                GTypeInfo type_info = {
-			sizeof (GthFilterClass),
-			NULL,
-			NULL,
-			(GClassInitFunc) gth_filter_class_init,
-			NULL,
-			NULL,
-			sizeof (GthFilter),
-			0,
-			(GInstanceInitFunc) gth_filter_init
-		};
-		static const GInterfaceInfo dom_domizable_info = {
-			(GInterfaceInitFunc) gth_filter_dom_domizable_interface_init,
-			(GInterfaceFinalizeFunc) NULL,
-			NULL
-		};
-		static const GInterfaceInfo gth_duplicable_info = {
-			(GInterfaceInitFunc) gth_filter_gth_duplicable_interface_init,
-			(GInterfaceFinalizeFunc) NULL,
-			NULL
-		};
-
-		type = g_type_register_static (GTH_TYPE_TEST,
-					       "GthFilter",
-					       &type_info,
-					       0);
-		g_type_add_interface_static (type, DOM_TYPE_DOMIZABLE, &dom_domizable_info);
-		g_type_add_interface_static (type, GTH_TYPE_DUPLICABLE, &gth_duplicable_info);
-	}
-
-        return type;
-}
-
-
 GthFilter*
 gth_filter_new (void)
 {
