@@ -93,8 +93,10 @@ struct _GthFolderTreePrivate
 };
 
 
-static gpointer parent_class = NULL;
-static guint    gth_folder_tree_signals[LAST_SIGNAL] = { 0 };
+static guint gth_folder_tree_signals[LAST_SIGNAL] = { 0 };
+
+
+G_DEFINE_TYPE (GthFolderTree, gth_folder_tree, GTK_TYPE_TREE_VIEW)
 
 
 static void
@@ -116,7 +118,7 @@ gth_folder_tree_finalize (GObject *object)
 		folder_tree->priv = NULL;
 	}
 
-	G_OBJECT_CLASS (parent_class)->finalize (object);
+	G_OBJECT_CLASS (gth_folder_tree_parent_class)->finalize (object);
 }
 
 
@@ -126,8 +128,6 @@ gth_folder_tree_class_init (GthFolderTreeClass *class)
 	GObjectClass   *object_class;
 	GtkWidgetClass *widget_class;
 
-	parent_class = g_type_class_peek_parent (class);
-
 	object_class = (GObjectClass*) class;
 	object_class->finalize = gth_folder_tree_finalize;
 
@@ -549,11 +549,11 @@ motion_notify_event_cb (GtkWidget      *widget,
 						 event->x,
 						 event->y))
 		{
-			GtkTreePath    *path = NULL;
-			GdkDragContext *context;
-			int             cell_x;
-			int             cell_y;
-			GdkPixmap      *dnd_icon;
+			GtkTreePath     *path = NULL;
+			GdkDragContext  *context;
+			int              cell_x;
+			int              cell_y;
+			cairo_surface_t *dnd_surface;
 
 			if (! gtk_tree_view_get_path_at_pos (GTK_TREE_VIEW (folder_tree),
 							     event->x,
@@ -577,15 +577,10 @@ motion_notify_event_cb (GtkWidget      *widget,
 						  1,
 						  (GdkEvent *) event);
 
-			dnd_icon = gtk_tree_view_create_row_drag_icon (GTK_TREE_VIEW (folder_tree), path);
-			gtk_drag_set_icon_pixmap (context,
-						  gdk_drawable_get_colormap (dnd_icon),
-						  dnd_icon,
-						  NULL,
-						  cell_x,
-						  cell_y);
+			dnd_surface = gtk_tree_view_create_row_drag_icon (GTK_TREE_VIEW (folder_tree), path);
+			gtk_drag_set_icon_surface (context, dnd_surface);
 
-			g_object_unref (dnd_icon);
+			cairo_surface_destroy (dnd_surface);
 			gtk_tree_path_free (path);
 		}
 
@@ -1059,34 +1054,6 @@ gth_folder_tree_init (GthFolderTree *folder_tree)
 }
 
 
-GType
-gth_folder_tree_get_type (void)
-{
-	static GType type = 0;
-
-	if (! type) {
-		GTypeInfo type_info = {
-			sizeof (GthFolderTreeClass),
-			NULL,
-			NULL,
-			(GClassInitFunc) gth_folder_tree_class_init,
-			NULL,
-			NULL,
-			sizeof (GthFolderTree),
-			0,
-			(GInstanceInitFunc) gth_folder_tree_init
-		};
-
-		type = g_type_register_static (GTK_TYPE_TREE_VIEW,
-					       "GthFolderTree",
-					       &type_info,
-					       0);
-	}
-
-	return type;
-}
-
-
 GtkWidget *
 gth_folder_tree_new (const char *uri)
 {
@@ -1123,7 +1090,7 @@ gth_folder_tree_set_list (GthFolderTree *folder_tree,
 		GtkTreeIter  iter;
 
 		sort_key = g_utf8_collate_key_for_filename (PARENT_URI, -1);
-		pixbuf = gtk_widget_render_icon (GTK_WIDGET (folder_tree), GTK_STOCK_GO_UP, GTK_ICON_SIZE_MENU, "folder-list");
+		pixbuf = gtk_widget_render_icon_pixbuf (GTK_WIDGET (folder_tree), GTK_STOCK_GO_UP, GTK_ICON_SIZE_MENU);
 
 		gtk_tree_store_append (folder_tree->priv->tree_store, &iter, NULL);
 		gtk_tree_store_set (folder_tree->priv->tree_store, &iter,
