@@ -42,13 +42,13 @@ struct _GthImageLoaderPrivate {
 };
 
 
-static gpointer parent_class = NULL;
+G_DEFINE_TYPE (GthImageLoader, gth_image_loader, G_TYPE_OBJECT)
 
 
 static void
 gth_image_loader_finalize (GObject *object)
 {
-	G_OBJECT_CLASS (parent_class)->finalize (object);
+	G_OBJECT_CLASS (gth_image_loader_parent_class)->finalize (object);
 }
 
 
@@ -57,7 +57,6 @@ gth_image_loader_class_init (GthImageLoaderClass *class)
 {
 	GObjectClass *object_class;
 
-	parent_class = g_type_class_peek_parent (class);
 	g_type_class_add_private (class, sizeof (GthImageLoaderPrivate));
 
 	object_class = G_OBJECT_CLASS (class);
@@ -77,34 +76,6 @@ gth_image_loader_init (GthImageLoader *self)
 }
 
 
-GType
-gth_image_loader_get_type (void)
-{
-	static GType type = 0;
-
-	if (! type) {
-		GTypeInfo type_info = {
-			sizeof (GthImageLoaderClass),
-			NULL,
-			NULL,
-			(GClassInitFunc) gth_image_loader_class_init,
-			NULL,
-			NULL,
-			sizeof (GthImageLoader),
-			0,
-			(GInstanceInitFunc) gth_image_loader_init
-		};
-
-		type = g_type_register_static (G_TYPE_OBJECT,
-					       "GthImageLoader",
-					       &type_info,
-					       0);
-	}
-
-	return type;
-}
-
-
 GthImageLoader *
 gth_image_loader_new (GthImageLoaderFunc loader_func,
 		      gpointer           loader_data)
@@ -233,18 +204,17 @@ load_pixbuf_thread (GSimpleAsyncResult *result,
 			error = g_error_new_literal (G_IO_ERROR, G_IO_ERROR_NOT_SUPPORTED, _("No suitable loader available for this file type"));
 	}
 
-	if (error != NULL) {
-		_g_object_unref (image);
-		g_simple_async_result_set_from_error (result, error);
-		g_error_free (error);
-		return;
-	}
-
 	load_result = g_new0 (LoadResult, 1);
 	load_result->image = image;
 	load_result->original_width = original_width;
 	load_result->original_height = original_height;
-	g_simple_async_result_set_op_res_gpointer (result, load_result, (GDestroyNotify) load_result_unref);
+
+	if (error != NULL) {
+		g_simple_async_result_set_from_error (result, error);
+		g_error_free (error);
+	}
+	else
+		g_simple_async_result_set_op_res_gpointer (result, load_result, (GDestroyNotify) load_result_unref);
 }
 
 
