@@ -39,7 +39,7 @@ struct _GthImagePrivate {
 };
 
 
-static gpointer parent_class = NULL;
+G_DEFINE_TYPE (GthImage, gth_image, G_TYPE_OBJECT)
 
 
 static void
@@ -76,25 +76,44 @@ gth_image_finalize (GObject *object)
 	_gth_image_free_data (GTH_IMAGE (object));
 
 	/* Chain up */
-	G_OBJECT_CLASS (parent_class)->finalize (object);
+	G_OBJECT_CLASS (gth_image_parent_class)->finalize (object);
+}
+
+
+static gboolean
+base_get_is_zoomable (GthImage *image)
+{
+	return FALSE;
+}
+
+
+static gboolean
+base_set_zoom (GthImage *image,
+	       double    zoom,
+	       int      *original_width,
+	       int      *original_height)
+{
+	return FALSE;
 }
 
 
 static void
-gth_image_class_init (GthImageClass *class)
+gth_image_class_init (GthImageClass *klass)
 {
 	GObjectClass *gobject_class;
 
-	parent_class = g_type_class_peek_parent (class);
-	g_type_class_add_private (class, sizeof (GthImagePrivate));
+	g_type_class_add_private (klass, sizeof (GthImagePrivate));
 
-	gobject_class = (GObjectClass*) class;
+	gobject_class = (GObjectClass*) klass;
 	gobject_class->finalize = gth_image_finalize;
+
+	klass->get_is_zoomable = base_get_is_zoomable;
+	klass->set_zoom = base_set_zoom;
 }
 
 
 static void
-gth_image_instance_init (GthImage *self)
+gth_image_init (GthImage *self)
 {
 	self->priv = G_TYPE_INSTANCE_GET_PRIVATE (self, GTH_TYPE_IMAGE, GthImagePrivate);
 	self->priv->format = GTH_IMAGE_FORMAT_CAIRO_SURFACE;
@@ -102,34 +121,6 @@ gth_image_instance_init (GthImage *self)
 }
 
 
-GType
-gth_image_get_type (void)
-{
-	static GType type = 0;
-
-	if (! type) {
-		GTypeInfo type_info = {
-			sizeof (GthImageClass),
-			NULL,
-			NULL,
-			(GClassInitFunc) gth_image_class_init,
-			NULL,
-			NULL,
-			sizeof (GthImage),
-			0,
-			(GInstanceInitFunc) gth_image_instance_init
-		};
-
-		type = g_type_register_static (G_TYPE_OBJECT,
-					       "GthImage",
-					       &type_info,
-					       0);
-	}
-
-	return type;
-}
-
-
 GthImage *
 gth_image_new (void)
 {
@@ -193,6 +184,26 @@ gth_image_get_cairo_surface (GthImage *image)
 }
 
 
+gboolean
+gth_image_get_is_zoomable (GthImage *self)
+{
+	if (self == NULL)
+		return FALSE;
+	else
+		return GTH_IMAGE_GET_CLASS (self)->get_is_zoomable (self);
+}
+
+
+gboolean
+gth_image_set_zoom (GthImage *self,
+		    double    zoom,
+		    int      *original_width,
+		    int      *original_height)
+{
+	return GTH_IMAGE_GET_CLASS (self)->set_zoom (self, zoom, original_width, original_height);
+}
+
+
 void
 gth_image_set_pixbuf (GthImage  *image,
 		      GdkPixbuf *value)
@@ -220,7 +231,7 @@ gth_image_get_pixbuf (GthImage *image)
 		break;
 
 	case GTH_IMAGE_FORMAT_GDK_PIXBUF:
-		result = _g_object_ref (image->priv->data.pixbuf);
+		result = g_object_ref (image->priv->data.pixbuf);
 		break;
 
 	case GTH_IMAGE_FORMAT_GDK_PIXBUF_ANIMATION:
@@ -272,8 +283,7 @@ gth_image_get_pixbuf_animation (GthImage *image)
 		break;
 
 	case GTH_IMAGE_FORMAT_GDK_PIXBUF:
-		if (image->priv->data.pixbuf != NULL)
-			result = gdk_pixbuf_non_anim_new (image->priv->data.pixbuf);
+		result = gdk_pixbuf_non_anim_new (image->priv->data.pixbuf);
 		break;
 
 	case GTH_IMAGE_FORMAT_GDK_PIXBUF_ANIMATION:
