@@ -25,7 +25,6 @@
 #include <glib.h>
 #include <glib-object.h>
 #include <gobject/gvaluecollector.h>
-#include "gconf-utils.h"
 #include "glib-utils.h"
 #include "gth-duplicable.h"
 #include "gth-filter.h"
@@ -41,8 +40,6 @@
 #include <gdk/gdkx.h>
 #endif
 
-#include "eggsmclient.h"
-#include "eggdesktopfile.h"
 
 static GStaticMutex register_mutex = G_STATIC_MUTEX_INIT;
 
@@ -116,7 +113,7 @@ struct _GthMainPrivate
 };
 
 
-static GObjectClass *parent_class = NULL;
+G_DEFINE_TYPE (GthMain, gth_main, G_TYPE_OBJECT)
 
 
 static void
@@ -146,17 +143,16 @@ gth_main_finalize (GObject *object)
 
 		if (gth_main->priv->bookmarks != NULL)
 			g_bookmark_file_free (gth_main->priv->bookmarks);
-
-		_g_object_unref (gth_main->priv->monitor);
-		_g_object_unref (gth_main->priv->extension_manager);
-		gth_filter_file_free (gth_main->priv->filters);
-		gth_tags_file_free (gth_main->priv->tags);
+		if (gth_main->priv->monitor != NULL)
+			g_object_unref (gth_main->priv->monitor);
+		if (gth_main->priv->extension_manager != NULL)
+			g_object_unref (gth_main->priv->extension_manager);
 
 		g_free (gth_main->priv);
 		gth_main->priv = NULL;
 	}
 
-	G_OBJECT_CLASS (parent_class)->finalize (object);
+	G_OBJECT_CLASS (gth_main_parent_class)->finalize (object);
 }
 
 
@@ -165,9 +161,7 @@ gth_main_class_init (GthMainClass *class)
 {
 	GObjectClass *object_class;
 
-	parent_class = g_type_class_peek_parent (class);
 	object_class = (GObjectClass*) class;
-
 	object_class->finalize = gth_main_finalize;
 }
 
@@ -188,50 +182,13 @@ gth_main_init (GthMain *main)
 }
 
 
-GType
-gth_main_get_type (void)
-{
-	static GType type = 0;
-
-	if (! type) {
-		GTypeInfo type_info = {
-			sizeof (GthMainClass),
-			NULL,
-			NULL,
-			(GClassInitFunc) gth_main_class_init,
-			NULL,
-			NULL,
-			sizeof (GthMain),
-			0,
-			(GInstanceInitFunc) gth_main_init
-		};
-
-		type = g_type_register_static (G_TYPE_OBJECT,
-					       "GthMain",
-					       &type_info,
-					       0);
-	}
-
-	return type;
-}
-
-
 void
 gth_main_initialize (void)
 {
 	if (Main != NULL)
 		return;
+
 	Main = (GthMain*) g_object_new (GTH_TYPE_MAIN, NULL);
-
-#ifdef GDK_WINDOWING_X11
-	egg_set_desktop_file (GTHUMB_APPLICATIONS_DIR "/gthumb.desktop");
-#else
-	/* manually set name and icon */
-	g_set_application_name (_("gThumb"));
-	gtk_window_set_default_icon_name ("gthumb");
-#endif
-
-	gtk_icon_theme_append_search_path (gtk_icon_theme_get_default (), GTHUMB_ICON_DIR);
 }
 
 
@@ -787,12 +744,16 @@ gth_main_get_pixbuf_saver (const char *mime_type)
 GthTest *
 gth_main_get_general_filter (void)
 {
-	char    *filter_name;
-	GthTest *filter;
+	GSettings *settings;
+	char      *filter_name;
+	GthTest   *filter;
+
+	settings = g_settings_new (GTHUMB_BROWSER_SCHEMA);
+	filter_name = g_settings_get_string (settings, PREF_BROWSER_GENERAL_FILTER);
+	filter = gth_main_get_registered_object (GTH_TYPE_TEST, filter_name);
 
-	filter_name = eel_gconf_get_string (PREF_GENERAL_FILTER, DEFAULT_GENERAL_FILTER);
-	filter =  gth_main_get_registered_object (GTH_TYPE_TEST, filter_name);
 	g_free (filter_name);
+	g_object_unref (settings);
 
 	return filter;
 }
@@ -816,6 +777,7 @@ gth_main_add_general_filter (GthTest *original_filter)
 
 		new_chain = gth_test_chain_new (GTH_MATCH_TYPE_ALL, NULL);
 		gth_test_chain_add_test (GTH_TEST_CHAIN (new_chain), test);
+		g_object_unref (test);
 
 		if (strncmp (gth_test_get_id (test), "file::type::", 12) != 0) {
 			GthTest *file_type_filter;
@@ -827,7 +789,6 @@ gth_main_add_general_filter (GthTest *original_filter)
 		gth_filter_set_test (filter, GTH_TEST_CHAIN (new_chain));
 		g_object_unref (new_chain);
 
-		g_object_unref (test);
 		test = (GthTest*) filter;
 	}
 	else {
@@ -1243,46 +1204,42 @@ gth_main_activate_extensions (void)
 						"rename_series",
 						"resize_images",
 						"search",
+						"selections",
 						"slideshow",
 						"webalbums",
 						NULL };
-	int                  i;
-	GError              *error = NULL;
-	GSList              *active_extensions;
-	GthExtensionManager *manager;
-	GSList              *scan;
+	int                   i;
+	GError               *error = NULL;
+	GSettings            *settings;
+	char                **active_extensions;
+	GList                *ordered_extensions;
+	GthExtensionManager  *manager;
+	GList                *scan;
 
 	if (Main->priv->extension_manager == NULL)
 		Main->priv->extension_manager = gth_extension_manager_new ();
 
 	for (i = 0; mandatory_extensions[i] != NULL; i++) {
 		if (! gth_extension_manager_activate (Main->priv->extension_manager, mandatory_extensions[i], &error)) {
-			g_warning ("Could not load the '%s' extension: %s", mandatory_extensions[i], error->message);
-			g_clear_error (&error);
+			g_critical ("Could not load the mandatory extension '%s': %s", mandatory_extensions[i], error->message);
+			abort ();
 		}
 	}
 
-	active_extensions = eel_gconf_get_string_list_with_error (PREF_ACTIVE_EXTENSIONS, &error);
-	if ((error != NULL)
-	    || ((active_extensions != NULL)
-	        && (active_extensions->next == NULL)
-	        && (g_strcmp0 (active_extensions->data, "default") == 0)))
+	settings = g_settings_new (GTHUMB_GENERAL_SCHEMA);
+	active_extensions = g_settings_get_strv (settings, PREF_GENERAL_ACTIVE_EXTENSIONS);
+	if ((active_extensions != NULL)
+	     && (active_extensions[1] == NULL)
+	     && (g_strcmp0 (active_extensions[0], "default") == 0))
 	{
-		g_clear_error (&error);
-		g_slist_foreach (active_extensions, (GFunc) g_free, NULL);
-		g_slist_free (active_extensions);
-
-		active_extensions = NULL;
-		for (i = 0; default_extensions[i] != NULL; i++)
-			active_extensions = g_slist_prepend (active_extensions, g_strdup (default_extensions[i]));
-
-		eel_gconf_set_string_list (PREF_ACTIVE_EXTENSIONS, active_extensions);
+		g_strfreev (active_extensions);
+		active_extensions = g_strdupv ((char **) default_extensions);
+		g_settings_set_strv (settings, PREF_GENERAL_ACTIVE_EXTENSIONS, (const char *const *) active_extensions);
 	}
-	active_extensions = gth_extension_manager_order_extensions (Main->priv->extension_manager, active_extensions);
+	ordered_extensions = gth_extension_manager_order_extensions (Main->priv->extension_manager, active_extensions);
 
 	manager = gth_main_get_default_extension_manager ();
-
-	for (scan = active_extensions; scan; scan = scan->next) {
+	for (scan = ordered_extensions; scan; scan = scan->next) {
 		char                    *name = scan->data;
 		GthExtensionDescription *description;
 		GError                  *error = NULL;
@@ -1297,8 +1254,8 @@ gth_main_activate_extensions (void)
 		}
 	}
 
-	g_slist_foreach (active_extensions, (GFunc) g_free, NULL);
-	g_slist_free (active_extensions);
+	_g_string_list_free (ordered_extensions);
+	g_strfreev (active_extensions);
 }
 
 
@@ -1362,7 +1319,7 @@ attribute_list_reload_required (const char *old_attributes,
 				}
 			}
 
-		g_object_unref (provider);
+		g_object_ref (provider);
 	}
 
 	/*
