@@ -58,7 +58,8 @@ struct _GthTaskProgressClass {
 	GtkHBoxClass parent_class;
 };
 
-static gpointer gth_task_progress_parent_class = NULL;
+
+G_DEFINE_TYPE (GthTaskProgress, gth_task_progress, GTK_TYPE_HBOX)
 
 
 static void
@@ -82,7 +83,6 @@ gth_task_progress_finalize (GObject *base)
 static void
 gth_task_progress_class_init (GthTaskProgressClass *klass)
 {
-	gth_task_progress_parent_class = g_type_class_peek_parent (klass);
 	G_OBJECT_CLASS (klass)->finalize = gth_task_progress_finalize;
 }
 
@@ -107,7 +107,7 @@ gth_task_progress_init (GthTaskProgress *self)
 	self->task_completed = 0;
 	self->pulse_event = 0;
 
-	vbox = gtk_vbox_new (FALSE, 3);
+	vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 3);
 	gtk_container_set_border_width (GTK_CONTAINER (vbox), 5);
 	gtk_widget_show (vbox);
 	gtk_box_pack_start (GTK_BOX (self), vbox, TRUE, TRUE, 0);
@@ -132,7 +132,7 @@ gth_task_progress_init (GthTaskProgress *self)
 	gtk_widget_show (self->details_label);
 	gtk_box_pack_start (GTK_BOX (vbox), self->details_label, FALSE, FALSE, 0);
 
-	vbox = gtk_vbox_new (FALSE, 0);
+	vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
 	gtk_widget_show (vbox);
 	gtk_box_pack_start (GTK_BOX (self), vbox, FALSE, FALSE, 0);
 
@@ -150,34 +150,6 @@ gth_task_progress_init (GthTaskProgress *self)
 }
 
 
-GType
-gth_task_progress_get_type (void)
-{
-	static GType type = 0;
-
-	if (type == 0) {
-		static const GTypeInfo g_define_type_info = {
-			sizeof (GthTaskProgressClass),
-			(GBaseInitFunc) NULL,
-			(GBaseFinalizeFunc) NULL,
-			(GClassInitFunc) gth_task_progress_class_init,
-			(GClassFinalizeFunc) NULL,
-			NULL,
-			sizeof (GthTaskProgress),
-			0,
-			(GInstanceInitFunc) gth_task_progress_init,
-			NULL
-		};
-		type = g_type_register_static (GTK_TYPE_HBOX,
-					       "GthTaskProgress",
-					       &g_define_type_info,
-					       0);
-	}
-
-	return type;
-}
-
-
 static gboolean
 task_pulse_cb (gpointer user_data)
 {
@@ -266,9 +238,6 @@ gth_task_progress_new (GthTask *task)
 /* -- gth_progress_dialog -- */
 
 
-static gpointer gth_progress_dialog_parent_class = NULL;
-
-
 struct _GthProgressDialogPrivate {
 	GtkWindow *parent;
 	GtkWidget *task_box;
@@ -277,6 +246,9 @@ struct _GthProgressDialogPrivate {
 };
 
 
+G_DEFINE_TYPE (GthProgressDialog, gth_progress_dialog, GTK_TYPE_DIALOG)
+
+
 static void
 gth_progress_dialog_finalize (GObject *base)
 {
@@ -294,7 +266,6 @@ gth_progress_dialog_finalize (GObject *base)
 static void
 gth_progress_dialog_class_init (GthProgressDialogClass *klass)
 {
-	gth_progress_dialog_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (GthProgressDialogPrivate));
 
 	G_OBJECT_CLASS (klass)->finalize = gth_progress_dialog_finalize;
@@ -325,7 +296,7 @@ gth_progress_dialog_init (GthProgressDialog *self)
 
 	gtk_dialog_add_button (GTK_DIALOG (self), GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE);
 
-	self->priv->task_box = gtk_vbox_new (FALSE, 6);
+	self->priv->task_box = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
 	gtk_widget_show (self->priv->task_box);
 	gtk_container_set_border_width (GTK_CONTAINER (self->priv->task_box), 5);
 	gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (self))), self->priv->task_box, FALSE, FALSE, 0);
@@ -335,34 +306,6 @@ gth_progress_dialog_init (GthProgressDialog *self)
 }
 
 
-GType
-gth_progress_dialog_get_type (void)
-{
-	static GType type = 0;
-
-	if (type == 0) {
-		static const GTypeInfo g_define_type_info = {
-			sizeof (GthProgressDialogClass),
-			(GBaseInitFunc) NULL,
-			(GBaseFinalizeFunc) NULL,
-			(GClassInitFunc) gth_progress_dialog_class_init,
-			(GClassFinalizeFunc) NULL,
-			NULL,
-			sizeof (GthProgressDialog),
-			0,
-			(GInstanceInitFunc) gth_progress_dialog_init,
-			NULL
-		};
-		type = g_type_register_static (GTK_TYPE_DIALOG,
-					       "GthProgressDialog",
-					       &g_define_type_info,
-					       0);
-	}
-
-	return type;
-}
-
-
 GtkWidget *
 gth_progress_dialog_new (GtkWindow *parent)
 {
