@@ -63,9 +63,21 @@ struct _GthTestCategoryPrivate
 };
 
 
-static gpointer parent_class = NULL;
-static DomDomizableIface *dom_domizable_parent_iface = NULL;
-static GthDuplicableIface *gth_duplicable_parent_iface = NULL;
+static DomDomizableInterface *dom_domizable_parent_iface = NULL;
+static GthDuplicableInterface *gth_duplicable_parent_iface = NULL;
+
+
+static void gth_test_category_dom_domizable_interface_init (DomDomizableInterface * iface);
+static void gth_test_category_gth_duplicable_interface_init (GthDuplicableInterface *iface);
+
+
+G_DEFINE_TYPE_WITH_CODE (GthTestCategory,
+			 gth_test_category,
+			 GTH_TYPE_TEST,
+			 G_IMPLEMENT_INTERFACE (DOM_TYPE_DOMIZABLE,
+					 	gth_test_category_dom_domizable_interface_init)
+		         G_IMPLEMENT_INTERFACE (GTH_TYPE_DUPLICABLE,
+		        		 	gth_test_category_gth_duplicable_interface_init))
 
 
 static void
@@ -85,7 +97,7 @@ gth_test_category_finalize (GObject *object)
 		test->priv = NULL;
 	}
 
-	G_OBJECT_CLASS (parent_class)->finalize (object);
+	G_OBJECT_CLASS (gth_test_category_parent_class)->finalize (object);
 }
 
 
@@ -162,10 +174,7 @@ static void
 monitor_tags_changed_cb (GthMonitor *monitor,
 		 	 gpointer    user_data)
 {
-	GthTestCategory *test = user_data;
-
-	if (test->priv->tag_store != NULL)
-		update_tag_list (test);
+	update_tag_list (GTH_TEST_CATEGORY (user_data));
 }
 
 
@@ -178,11 +187,7 @@ gth_test_category_real_create_control (GthTest *base)
 
 	test = (GthTestCategory *) base;
 
-	control = gtk_hbox_new (FALSE, 6);
-	g_signal_connect (control,
-			  "destroy",
-			  G_CALLBACK (gtk_widget_destroyed),
-			  &test->priv->tag_store);
+	control = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
 
 	/* text operation combo box */
 
@@ -233,11 +238,10 @@ gth_test_category_real_create_control (GthTest *base)
 			  "changed",
 			  G_CALLBACK (combo_entry_changed_cb),
 			  test);
-	if (test->priv->monitor_events == 0)
-		test->priv->monitor_events = g_signal_connect (gth_main_get_default_monitor (),
-							       "tags-changed",
-							       G_CALLBACK (monitor_tags_changed_cb),
-							       test);
+	test->priv->monitor_events = g_signal_connect (gth_main_get_default_monitor (),
+						       "tags-changed",
+						       G_CALLBACK (monitor_tags_changed_cb),
+						       test);
 	/**/
 
 	gtk_box_pack_start (GTK_BOX (control), test->priv->op_combo_box, FALSE, FALSE, 0);
@@ -413,11 +417,10 @@ gth_test_category_class_init (GthTestCategoryClass *class)
 	GObjectClass *object_class;
 	GthTestClass *test_class;
 
-	parent_class = g_type_class_peek_parent (class);
 	object_class = (GObjectClass*) class;
-	test_class = (GthTestClass *) class;
-
 	object_class->finalize = gth_test_category_finalize;
+
+	test_class = (GthTestClass *) class;
 	test_class->create_control = gth_test_category_real_create_control;
 	test_class->update_from_control = gth_test_category_real_update_from_control;
 	test_class->match = gth_test_category_real_match;
@@ -425,7 +428,7 @@ gth_test_category_class_init (GthTestCategoryClass *class)
 
 
 static void
-gth_test_category_dom_domizable_interface_init (DomDomizableIface * iface)
+gth_test_category_dom_domizable_interface_init (DomDomizableInterface * iface)
 {
 	dom_domizable_parent_iface = g_type_interface_peek_parent (iface);
 	iface->create_element = gth_test_category_real_create_element;
@@ -434,7 +437,7 @@ gth_test_category_dom_domizable_interface_init (DomDomizableIface * iface)
 
 
 static void
-gth_test_category_gth_duplicable_interface_init (GthDuplicableIface *iface)
+gth_test_category_gth_duplicable_interface_init (GthDuplicableInterface *iface)
 {
 	gth_duplicable_parent_iface = g_type_interface_peek_parent (iface);
 	iface->duplicate = gth_test_category_real_duplicate;
@@ -449,46 +452,6 @@ gth_test_category_init (GthTestCategory *test)
 }
 
 
-GType
-gth_test_category_get_type (void)
-{
-        static GType type = 0;
-
-        if (! type) {
-                GTypeInfo type_info = {
-			sizeof (GthTestCategoryClass),
-			NULL,
-			NULL,
-			(GClassInitFunc) gth_test_category_class_init,
-			NULL,
-			NULL,
-			sizeof (GthTestCategory),
-			0,
-			(GInstanceInitFunc) gth_test_category_init
-		};
-		static const GInterfaceInfo dom_domizable_info = {
-			(GInterfaceInitFunc) gth_test_category_dom_domizable_interface_init,
-			(GInterfaceFinalizeFunc) NULL,
-			NULL
-		};
-		static const GInterfaceInfo gth_duplicable_info = {
-			(GInterfaceInitFunc) gth_test_category_gth_duplicable_interface_init,
-			(GInterfaceFinalizeFunc) NULL,
-			NULL
-		};
-
-		type = g_type_register_static (GTH_TYPE_TEST,
-					       "GthTestCategory",
-					       &type_info,
-					       0);
-		g_type_add_interface_static (type, DOM_TYPE_DOMIZABLE, &dom_domizable_info);
-		g_type_add_interface_static (type, GTH_TYPE_DUPLICABLE, &gth_duplicable_info);
-	}
-
-        return type;
-}
-
-
 void
 gth_test_category_set (GthTestCategory *self,
 		       GthTestOp        op,
