@@ -72,7 +72,7 @@ enum {
 };
 
 
-static GObjectClass *parent_class = NULL;
+G_DEFINE_TYPE (GthThumbLoader, gth_thumb_loader, G_TYPE_OBJECT)
 
 
 static void
@@ -84,7 +84,7 @@ gth_thumb_loader_finalize (GObject *object)
 	_g_object_unref (self->priv->iloader);
 	_g_object_unref (self->priv->tloader);
 
-	G_OBJECT_CLASS (parent_class)->finalize (object);
+	G_OBJECT_CLASS (gth_thumb_loader_parent_class)->finalize (object);
 }
 
 
@@ -93,7 +93,6 @@ gth_thumb_loader_class_init (GthThumbLoaderClass *class)
 {
 	GObjectClass *object_class;
 
-	parent_class = g_type_class_peek_parent (class);
 	g_type_class_add_private (class, sizeof (GthThumbLoaderPrivate));
 
 	object_class = G_OBJECT_CLASS (class);
@@ -111,34 +110,6 @@ gth_thumb_loader_init (GthThumbLoader *self)
 }
 
 
-GType
-gth_thumb_loader_get_type (void)
-{
-	static GType type = 0;
-
-	if (! type) {
-		GTypeInfo type_info = {
-			sizeof (GthThumbLoaderClass),
-			NULL,
-			NULL,
-			(GClassInitFunc) gth_thumb_loader_class_init,
-			NULL,
-			NULL,
-			sizeof (GthThumbLoader),
-			0,
-			(GInstanceInitFunc) gth_thumb_loader_init
-		};
-
-		type = g_type_register_static (G_TYPE_OBJECT,
-					       "GthThumbLoader",
-					       &type_info,
-					       0);
-	}
-
-	return type;
-}
-
-
 static GthImage *
 generate_thumbnail (GthFileData   *file_data,
 		    int            requested_size,
@@ -361,9 +332,7 @@ load_data_unref (LoadData *load_data)
 {
 	g_object_unref (load_data->thumb_loader);
 	g_object_unref (load_data->file_data);
-	_g_object_unref (load_data->simple);
 	_g_object_unref (load_data->cancellable);
-	g_free (load_data->thumbnailer_tmpfile);
 	g_free (load_data);
 }
 
@@ -837,7 +806,6 @@ gth_thumb_loader_load (GthThumbLoader      *self,
 
 			g_error_free (error);
 			g_free (uri);
-			g_object_unref (simple);
 
 			return;
 		}
@@ -858,7 +826,6 @@ gth_thumb_loader_load (GthThumbLoader      *self,
 		g_simple_async_result_complete_in_idle (simple);
 
 		g_error_free (error);
-		g_object_unref (simple);
 
 		return;
 	}
