@@ -52,10 +52,12 @@ struct _GthTimeSelectorPrivate
 };
 
 
-static GtkHBoxClass *parent_class = NULL;
 static guint gth_time_selector_signals[LAST_SIGNAL] = { 0 };
 
 
+G_DEFINE_TYPE (GthTimeSelector, gth_time_selector, GTK_TYPE_HBOX);
+
+
 static void
 gth_time_selector_finalize (GObject *object)
 {
@@ -66,16 +68,15 @@ gth_time_selector_finalize (GObject *object)
 	gtk_widget_destroy (self->priv->calendar_popup);
 	gth_datetime_free (self->priv->date_time);
 
-	G_OBJECT_CLASS (parent_class)->finalize (object);
+	G_OBJECT_CLASS (gth_time_selector_parent_class)->finalize (object);
 }
 
 
 static void
 gth_time_selector_class_init (GthTimeSelectorClass *class)
 {
-	GObjectClass   *object_class;
+	GObjectClass *object_class;
 
-	parent_class = g_type_class_peek_parent (class);
 	g_type_class_add_private (class, sizeof (GthTimeSelectorPrivate));
 
 	object_class = (GObjectClass*) class;
@@ -106,8 +107,9 @@ static void
 hide_calendar_popup (GthTimeSelector *self)
 {
 	gtk_grab_remove (self->priv->calendar_popup);
-	gdk_keyboard_ungrab (GDK_CURRENT_TIME);
-	gdk_pointer_ungrab (GDK_CURRENT_TIME);
+	/*gdk_keyboard_ungrab (GDK_CURRENT_TIME);*/
+	gdk_device_ungrab (gdk_device_manager_get_client_pointer (gdk_display_get_device_manager (gdk_window_get_display (gtk_widget_get_window (self->priv->calendar_popup)))),
+			   GDK_CURRENT_TIME);
 	gtk_widget_hide (self->priv->calendar_popup);
 
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (self->priv->calendar_button), FALSE);
@@ -117,16 +119,16 @@ hide_calendar_popup (GthTimeSelector *self)
 static void
 show_calendar_popup (GthTimeSelector *self)
 {
-	GtkRequisition  popup_req;
-	int             x;
-	int             y;
-	GtkAllocation   allocation;
-	int             selector_height;
-	GdkScreen      *screen;
-	gint            monitor_num;
-	GdkRectangle    monitor;
+	GtkRequisition         popup_req;
+	int                    x;
+	int                    y;
+	GtkAllocation          allocation;
+	int                    selector_height;
+	GdkScreen             *screen;
+	gint                   monitor_num;
+	cairo_rectangle_int_t  monitor;
 
-	gtk_widget_size_request (self->priv->popup_box, &popup_req);
+	gtk_widget_get_preferred_size (self->priv->popup_box, &popup_req, NULL);
 
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (self->priv->calendar_button), TRUE);
 
@@ -152,18 +154,19 @@ show_calendar_popup (GthTimeSelector *self)
 	gtk_window_move (GTK_WINDOW (self->priv->calendar_popup), x, y);
 	gtk_widget_show (self->priv->calendar_popup);
 
-	gdk_keyboard_grab (gtk_widget_get_window (self->priv->calendar_popup), TRUE, GDK_CURRENT_TIME);
+	/*gdk_keyboard_grab (gtk_widget_get_window (self->priv->calendar_popup), TRUE, GDK_CURRENT_TIME);*/
 	gtk_grab_add (self->priv->calendar_popup);
-	gdk_pointer_grab (gtk_widget_get_window (self->priv->calendar_popup),
-			  TRUE,
-			  (GDK_BUTTON_PRESS_MASK
-			   | GDK_BUTTON_RELEASE_MASK
-			   | GDK_POINTER_MOTION_HINT_MASK
-			   | GDK_BUTTON_MOTION_MASK
-			   | GDK_EXTENSION_EVENTS_ALL),
-			  NULL,
-			  NULL,
-			  GDK_CURRENT_TIME);
+	gdk_device_grab (gdk_device_manager_get_client_pointer (gdk_display_get_device_manager (gdk_window_get_display (gtk_widget_get_window (self->priv->calendar_popup)))),
+			 gtk_widget_get_window (self->priv->calendar_popup),
+			 GDK_OWNERSHIP_WINDOW,
+			 TRUE,
+			 (GDK_BUTTON_PRESS_MASK
+			  | GDK_BUTTON_RELEASE_MASK
+			  | GDK_POINTER_MOTION_HINT_MASK
+			  | GDK_BUTTON_MOTION_MASK
+			  | GDK_EXTENSION_EVENTS_ALL),
+			 NULL,
+			 GDK_CURRENT_TIME);
 	gtk_widget_grab_focus (self->priv->calendar);
 }
 
@@ -209,8 +212,6 @@ update_view_from_data (GthTimeSelector *self)
 			text = gth_datetime_strftime (self->priv->date_time, "%X");
 			entry = gtk_bin_get_child (GTK_BIN (self->priv->time_combo_box));
 			gtk_entry_set_text (GTK_ENTRY (entry), text);
-
-			g_free (text);
 		}
 		else {
 			GtkWidget *entry;
@@ -340,15 +341,14 @@ calendar_popup_button_press_event_cb (GtkWidget      *widget,
 				      GdkEventButton *event,
 				      gpointer        user_data)
 {
-	GthTimeSelector *self = user_data;
-	GdkRectangle     popup_area;
+	GthTimeSelector       *self = user_data;
+	cairo_rectangle_int_t  popup_area;
 
 	gdk_window_get_geometry (gtk_widget_get_window (self->priv->calendar_popup),
 				 &popup_area.x,
 				 &popup_area.y,
 				 &popup_area.width,
-				 &popup_area.height,
-				 NULL);
+				 &popup_area.height);
 
 	/*g_print ("(%.0f, %.0f) <==> (%d, %d)[%d, %d]\n", event->x_root, event->y_root,  popup_area.x,  popup_area.y, popup_area.width, popup_area.height);*/
 
@@ -372,7 +372,7 @@ calendar_popup_key_press_event_cb (GtkWidget   *widget,
 	GthTimeSelector *self = user_data;
 
 	switch (event->keyval) {
-	case GDK_Escape:
+	case GDK_KEY_Escape:
 		hide_calendar_popup (self);
 		break;
 
@@ -414,7 +414,7 @@ gth_time_selector_construct (GthTimeSelector *self)
 
 	g_object_set (self, "spacing", 6, NULL);
 
-	box = gtk_hbox_new (FALSE, 0);
+	box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
 	gtk_widget_show (box);
 	gtk_box_pack_start (GTK_BOX (self), box, FALSE, FALSE, 0);
 
@@ -448,7 +448,7 @@ gth_time_selector_construct (GthTimeSelector *self)
 	gtk_widget_show (frame);
 	gtk_container_add (GTK_CONTAINER (self->priv->calendar_popup), frame);
 
-	box = gtk_vbox_new (FALSE, 6);
+	box = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
 	gtk_container_set_border_width (GTK_CONTAINER (box), 6);
 	gtk_widget_show (box);
 	gtk_container_add (GTK_CONTAINER (frame), box);
@@ -466,7 +466,8 @@ gth_time_selector_construct (GthTimeSelector *self)
 					  G_CALLBACK (calendar_day_selected_cb),
 					  self);
 
-	button_box = gtk_hbox_new (TRUE, 6);
+	button_box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
+	gtk_box_set_homogeneous (GTK_BOX (button_box), TRUE);
 	gtk_widget_show (button_box);
 	gtk_box_pack_start (GTK_BOX (box), button_box, FALSE, FALSE, 0);
 
@@ -486,7 +487,7 @@ gth_time_selector_construct (GthTimeSelector *self)
 			  G_CALLBACK (now_button_clicked_cb),
 			  self);
 
-	time_box = gtk_hbox_new (FALSE, 0);
+	time_box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
 	gtk_widget_show (time_box);
 	gtk_box_pack_start (GTK_BOX (self), time_box, FALSE, FALSE, 0);
 
@@ -534,34 +535,6 @@ gth_time_selector_construct (GthTimeSelector *self)
 }
 
 
-GType
-gth_time_selector_get_type (void)
-{
-	static GType type = 0;
-
-	if (! type) {
-		GTypeInfo type_info = {
-			sizeof (GthTimeSelectorClass),
-			NULL,
-			NULL,
-			(GClassInitFunc) gth_time_selector_class_init,
-			NULL,
-			NULL,
-			sizeof (GthTimeSelector),
-			0,
-			(GInstanceInitFunc) gth_time_selector_init
-		};
-
-		type = g_type_register_static (GTK_TYPE_HBOX,
-					       "GthTimeSelector",
-					       &type_info,
-					       0);
-	}
-
-	return type;
-}
-
-
 GtkWidget *
 gth_time_selector_new (void)
 {
