@@ -27,9 +27,6 @@
 #include "gtk-utils.h"
 
 
-#define GTH_TOOLBOX_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GTH_TYPE_TOOLBOX, GthToolboxPrivate))
-
-
 enum {
 	GTH_TOOLBOX_LIST_PAGE = 0,
 	GTH_TOOLBOX_OPTIONS_PAGE
@@ -42,9 +39,6 @@ enum  {
 };
 
 
-static gpointer parent_class = NULL;
-
-
 struct _GthToolboxPrivate {
 	char      *name;
 	GtkWidget *box;
@@ -55,6 +49,9 @@ struct _GthToolboxPrivate {
 };
 
 
+G_DEFINE_TYPE (GthToolbox, gth_toolbox, GTK_TYPE_NOTEBOOK)
+
+
 static void
 gth_toolbox_set_name (GthToolbox *self,
 		      const char *name)
@@ -97,7 +94,7 @@ gth_toolbox_finalize (GObject *object)
 
 	g_free (self->priv->name);
 
-	G_OBJECT_CLASS (parent_class)->finalize (object);
+	G_OBJECT_CLASS (gth_toolbox_parent_class)->finalize (object);
 }
 
 
@@ -106,7 +103,6 @@ gth_toolbox_class_init (GthToolboxClass *klass)
 {
 	GObjectClass *gobject_class;
 
-	parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (GthToolboxPrivate));
 
 	gobject_class = (GObjectClass*) klass;
@@ -131,35 +127,35 @@ gth_toolbox_init (GthToolbox *toolbox)
 	GtkWidget *options_header;
 	GtkWidget *header_align;
 
-	toolbox->priv = GTH_TOOLBOX_GET_PRIVATE (toolbox);
+	toolbox->priv = G_TYPE_INSTANCE_GET_PRIVATE (toolbox, GTH_TYPE_TOOLBOX, GthToolboxPrivate);
 	gtk_notebook_set_show_tabs (GTK_NOTEBOOK (toolbox), FALSE);
 	gtk_notebook_set_show_border (GTK_NOTEBOOK (toolbox), FALSE);
 
-	/* tools vbox page */
+	/* tool list page */
 
 	scrolled = gtk_scrolled_window_new (NULL, NULL);
-	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolled), GTK_SHADOW_NONE);
+	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolled), GTK_SHADOW_IN);
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled),
 					GTK_POLICY_AUTOMATIC,
 					GTK_POLICY_AUTOMATIC);
 	gtk_widget_show (scrolled);
 	gtk_notebook_append_page (GTK_NOTEBOOK (toolbox), scrolled, NULL);
 
-	toolbox->priv->box = gtk_vbox_new (FALSE, 0);
+	toolbox->priv->box = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
 	gtk_box_set_spacing (GTK_BOX (toolbox->priv->box), 0);
 	gtk_widget_show (toolbox->priv->box);
 	gtk_scrolled_window_add_with_viewport (GTK_SCROLLED_WINDOW (scrolled), toolbox->priv->box);
 
 	/* tool options page */
 
-	options_box = gtk_vbox_new (FALSE, 0);
+	options_box = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
 	gtk_widget_show (options_box);
 	gtk_notebook_append_page (GTK_NOTEBOOK (toolbox), options_box, NULL);
 
 	header_align = gtk_alignment_new (0.0, 0.0, 1.0, 1.0);
 	gtk_alignment_set_padding (GTK_ALIGNMENT (header_align), 5, 5, 0, 0);
 
-	options_header = gtk_hbox_new (FALSE, 6);
+	options_header = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
 	gtk_widget_show (options_header);
 	gtk_container_add (GTK_CONTAINER (header_align), options_header);
 
@@ -176,41 +172,13 @@ gth_toolbox_init (GthToolbox *toolbox)
 	gtk_box_pack_start (GTK_BOX (options_box), header_align, FALSE, FALSE, 0);
 
 	toolbox->priv->options = gtk_scrolled_window_new (NULL, NULL);
-	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (toolbox->priv->options), GTK_SHADOW_NONE);
+	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (toolbox->priv->options), GTK_SHADOW_IN);
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (toolbox->priv->options), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 	gtk_widget_show (toolbox->priv->options);
 	gtk_box_pack_start (GTK_BOX (options_box), toolbox->priv->options, TRUE, TRUE, 0);
 }
 
 
-GType
-gth_toolbox_get_type (void)
-{
-	static GType type = 0;
-
-	if (! type) {
-		GTypeInfo type_info = {
-			sizeof (GthToolboxClass),
-			NULL,
-			NULL,
-			(GClassInitFunc) gth_toolbox_class_init,
-			NULL,
-			NULL,
-			sizeof (GthToolbox),
-			0,
-			(GInstanceInitFunc) gth_toolbox_init
-		};
-
-		type = g_type_register_static (GTK_TYPE_NOTEBOOK,
-					       "GthToolbox",
-					       &type_info,
-					       0);
-	}
-
-	return type;
-}
-
-
 static void
 child_clicked_cb (GtkWidget *tool,
 		  gpointer   data)
