@@ -21,13 +21,63 @@
 
 #include <config.h>
 #include <string.h>
-#include "gconf-utils.h"
 #include "gtk-utils.h"
 #include "pixbuf-utils.h"
 
 #define REQUEST_ENTRY_WIDTH_IN_CHARS 40
 
 
+void
+_gtk_action_group_add_actions_with_flags (GtkActionGroup          *action_group,
+					  const GthActionEntryExt *entries,
+					  guint                    n_entries,
+					  gpointer                 user_data)
+{
+	guint i;
+
+	g_return_if_fail (GTK_IS_ACTION_GROUP (action_group));
+
+	for (i = 0; i < n_entries; i++) {
+		GtkAction  *action;
+		const char *label;
+		const char *tooltip;
+
+		label = gtk_action_group_translate_string (action_group, entries[i].label);
+		tooltip = gtk_action_group_translate_string (action_group, entries[i].tooltip);
+
+		action = gtk_action_new (entries[i].name,
+					 label,
+					 tooltip,
+					 NULL);
+
+		if (entries[i].stock_id) {
+			g_object_set (action, "stock-id", entries[i].stock_id, NULL);
+			if (gtk_icon_theme_has_icon (gtk_icon_theme_get_default (), entries[i].stock_id))
+				g_object_set (action, "icon-name", entries[i].stock_id, NULL);
+		}
+
+		if (entries[i].callback) {
+			GClosure *closure;
+
+			closure = g_cclosure_new (entries[i].callback, user_data, NULL);
+			g_signal_connect_closure (action, "activate", closure, FALSE);
+		}
+
+		gtk_action_group_add_action_with_accel (action_group,
+							action,
+							entries[i].accelerator);
+
+		if (entries[i].flags & GTH_ACTION_FLAG_ALWAYS_SHOW_IMAGE)
+			gtk_action_set_always_show_image (action, TRUE);
+
+		if (entries[i].flags & GTH_ACTION_FLAG_IS_IMPORTANT)
+			gtk_action_set_is_important (action, TRUE);
+
+		g_object_unref (action);
+	}
+}
+
+
 GtkWidget *
 _gtk_button_new_from_stock_with_text (const char *stock_id,
 				      const char *text)
@@ -85,7 +135,7 @@ _gtk_message_dialog_new (GtkWindow        *parent,
 	if (stock_id == NULL)
 		stock_id = GTK_STOCK_DIALOG_INFO;
 
-	d = gtk_dialog_new_with_buttons ("", parent, flags, NULL);
+	d = gtk_dialog_new_with_buttons ("", parent, flags, NULL, NULL);
 	gtk_window_set_resizable (GTK_WINDOW (d), FALSE);
 
 	gtk_container_set_border_width (GTK_CONTAINER (d), 6);
@@ -116,7 +166,7 @@ _gtk_message_dialog_new (GtkWindow        *parent,
 	gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
 	gtk_label_set_selectable (GTK_LABEL (label), TRUE);
 
-	hbox = gtk_hbox_new (FALSE, 18);
+	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 18);
 	gtk_container_set_border_width (GTK_CONTAINER (hbox), 6);
 
 	gtk_box_pack_start (GTK_BOX (hbox), image,
@@ -172,7 +222,7 @@ _gtk_yesno_dialog_new (GtkWindow        *parent,
 	GtkWidget    *button;
 	char         *stock_id = GTK_STOCK_DIALOG_QUESTION;
 
-	d = gtk_dialog_new_with_buttons ("", parent, flags, NULL);
+	d = gtk_dialog_new_with_buttons ("", parent, flags, NULL, NULL);
 	gtk_window_set_resizable (GTK_WINDOW (d), FALSE);
 
 	gtk_container_set_border_width (GTK_CONTAINER (d), 6);
@@ -188,7 +238,7 @@ _gtk_yesno_dialog_new (GtkWindow        *parent,
 	gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
 	gtk_label_set_selectable (GTK_LABEL (label), TRUE);
 
-	hbox = gtk_hbox_new (FALSE, 12);
+	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 12);
 	gtk_container_set_border_width (GTK_CONTAINER (hbox), 6);
 
 	gtk_box_pack_start (GTK_BOX (hbox), image,
@@ -225,209 +275,6 @@ _gtk_yesno_dialog_new (GtkWindow        *parent,
 }
 
 
-static void
-yesno__check_button_toggled_cb (GtkToggleButton *button,
-				const char      *gconf_key)
-{
-	eel_gconf_set_boolean (gconf_key,
-			       ! gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)));
-}
-
-
-GtkWidget*
-_gtk_yesno_dialog_with_checkbutton_new (GtkWindow        *parent,
-					GtkDialogFlags    flags,
-					const char       *message,
-					const char       *no_button_text,
-					const char       *yes_button_text,
-					const char       *check_button_label,
-					const char       *gconf_key)
-{
-	GtkWidget *d;
-	GtkWidget *label;
-	GtkWidget *image;
-	GtkWidget *hbox;
-	GtkWidget *button;
-	GtkWidget *check_button;
-	char      *stock_id = GTK_STOCK_DIALOG_QUESTION;
-
-	d = gtk_dialog_new_with_buttons ("", parent, flags, NULL);
-	gtk_window_set_resizable (GTK_WINDOW (d), FALSE);
-
-	gtk_container_set_border_width (GTK_CONTAINER (d), 6);
-	gtk_container_set_border_width (GTK_CONTAINER (gtk_dialog_get_content_area (GTK_DIALOG (d))), 6);
-	gtk_box_set_spacing (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (d))), 8);
-
-	/* Add label and image */
-
-	image = gtk_image_new_from_stock (stock_id, GTK_ICON_SIZE_DIALOG);
-	gtk_misc_set_alignment (GTK_MISC (image), 0.5, 0.0);
-
-	label = gtk_label_new (message);
-	gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
-	gtk_label_set_selectable (GTK_LABEL (label), TRUE);
-
-	hbox = gtk_hbox_new (FALSE, 12);
-	gtk_container_set_border_width (GTK_CONTAINER (hbox), 6);
-
-	gtk_box_pack_start (GTK_BOX (hbox), image,
-			    FALSE, FALSE, 0);
-
-	gtk_box_pack_start (GTK_BOX (hbox), label,
-			    TRUE, TRUE, 0);
-
-	gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (d))),
-			    hbox,
-			    FALSE, FALSE, 0);
-
-	/* Add checkbutton */
-
-	check_button = gtk_check_button_new_with_mnemonic (check_button_label);
-	gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (d))),
-			    check_button,
-			    FALSE, FALSE, 0);
-	gtk_widget_show (check_button);
-
-	gtk_widget_show_all (hbox);
-
-	/* Add buttons */
-
-	button = _gtk_button_new_from_stock_with_text (GTK_STOCK_CANCEL, no_button_text);
-	gtk_dialog_add_action_widget (GTK_DIALOG (d),
-				      button,
-				      GTK_RESPONSE_CANCEL);
-
-	/**/
-
-	button = _gtk_button_new_from_stock_with_text (GTK_STOCK_OK, yes_button_text);
-	gtk_dialog_add_action_widget (GTK_DIALOG (d),
-				      button,
-				      GTK_RESPONSE_YES);
-
-	/**/
-
-	gtk_dialog_set_default_response (GTK_DIALOG (d), GTK_RESPONSE_YES);
-
-	g_signal_connect (G_OBJECT (check_button),
-			  "toggled",
-			  G_CALLBACK (yesno__check_button_toggled_cb),
-			  (gpointer) gconf_key);
-
-	return d;
-}
-
-
-GtkWidget*
-_gtk_message_dialog_with_checkbutton_new (GtkWindow        *parent,
-			 		  GtkDialogFlags    flags,
-			 		  const char       *stock_id,
-			 		  const char       *message,
-			 		  const char       *secondary_message,
-			 		  const char       *gconf_key,
-			 		  const char       *check_button_label,
-			 		  const char       *first_button_text,
-			 		  ...)
-{
-	GtkWidget  *d;
-	GtkWidget  *label;
-	GtkWidget  *image;
-	GtkWidget  *hbox;
-	GtkWidget  *check_button;
-	va_list     args;
-	const char *text;
-	int         response_id;
-	char       *escaped_message, *markup_text;
-
-	g_return_val_if_fail (message != NULL, NULL);
-
-	if (stock_id == NULL)
-		stock_id = GTK_STOCK_DIALOG_INFO;
-
-	d = gtk_dialog_new_with_buttons ("", parent, flags, NULL);
-	gtk_window_set_resizable (GTK_WINDOW (d), FALSE);
-
-	gtk_container_set_border_width (GTK_CONTAINER (d), 6);
-	gtk_container_set_border_width (GTK_CONTAINER (gtk_dialog_get_content_area (GTK_DIALOG (d))), 6);
-	gtk_box_set_spacing (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (d))), 8);
-
-	/* Add label and image */
-
-	image = gtk_image_new_from_stock (stock_id, GTK_ICON_SIZE_DIALOG);
-	gtk_misc_set_alignment (GTK_MISC (image), 0.5, 0.0);
-
-	label = gtk_label_new ("");
-
-	escaped_message = g_markup_escape_text (message, -1);
-	if (secondary_message != NULL) {
-		char *escaped_secondary_message = g_markup_escape_text (secondary_message, -1);
-		markup_text = g_strdup_printf ("<span weight=\"bold\" size=\"larger\">%s</span>\n\n%s",
-					       escaped_message,
-					       escaped_secondary_message);
-		g_free (escaped_secondary_message);
-	} else
-		markup_text = g_strdup (escaped_message);
-	gtk_label_set_markup (GTK_LABEL (label), markup_text);
-	g_free (markup_text);
-	g_free (escaped_message);
-
-	gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
-	gtk_label_set_selectable (GTK_LABEL (label), TRUE);
-
-	hbox = gtk_hbox_new (FALSE, 6);
-	gtk_container_set_border_width (GTK_CONTAINER (hbox), 6);
-
-	gtk_box_pack_start (GTK_BOX (hbox), image,
-			    FALSE, FALSE, 0);
-
-	gtk_box_pack_start (GTK_BOX (hbox), label,
-			    TRUE, TRUE, 0);
-
-	gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (d))),
-			    hbox,
-			    FALSE, FALSE, 0);
-
-	gtk_widget_show_all (hbox);
-
-	/* Add checkbutton */
-
-	check_button = gtk_check_button_new_with_mnemonic (check_button_label);
-	gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (d))),
-			    check_button,
-			    FALSE, FALSE, 0);
-	gtk_widget_show (check_button);
-
-	/* Add buttons */
-
-	if (first_button_text == NULL)
-		return d;
-
-	va_start (args, first_button_text);
-
-	text = first_button_text;
-	response_id = va_arg (args, gint);
-
-	while (text != NULL) {
-		gtk_dialog_add_button (GTK_DIALOG (d), text, response_id);
-
-		text = va_arg (args, gchar*);
-		if (text == NULL)
-			break;
-		response_id = va_arg (args, int);
-	}
-
-	va_end (args);
-
-	gtk_dialog_set_default_response (GTK_DIALOG (d), GTK_RESPONSE_YES);
-
-	g_signal_connect (G_OBJECT (check_button),
-			  "toggled",
-			  G_CALLBACK (yesno__check_button_toggled_cb),
-			  (gpointer) gconf_key);
-
-	return d;
-}
-
-
 void
 _gtk_error_dialog_from_gerror_run (GtkWindow   *parent,
 				   const char  *title,
@@ -635,7 +482,7 @@ _g_icon_get_pixbuf (GIcon        *icon,
 	pixbuf = NULL;
 	if (G_IS_THEMED_ICON (icon))
 		pixbuf = get_themed_icon_pixbuf (G_THEMED_ICON (icon), size, theme);
-	else if (G_IS_FILE_ICON (icon))
+	if (G_IS_FILE_ICON (icon))
 		pixbuf = get_file_icon_pixbuf (G_FILE_ICON (icon), size);
 
 	if (pixbuf == NULL)
@@ -900,8 +747,8 @@ _gtk_widget_get_screen_size (GtkWidget *widget,
 			     int       *width,
 			     int       *height)
 {
-	GdkScreen    *screen;
-	GdkRectangle  geometry;
+	GdkScreen             *screen;
+	cairo_rectangle_int_t  geometry;
 
 	screen = gtk_widget_get_screen (widget);
 	gdk_screen_get_monitor_geometry (screen,
@@ -913,6 +760,36 @@ _gtk_widget_get_screen_size (GtkWidget *widget,
 }
 
 
+int
+_gtk_widget_get_allocated_width (GtkWidget *widget)
+{
+	int width = 0;
+
+	if ((widget != NULL) && gtk_widget_get_mapped (widget)) {
+		width = gtk_widget_get_allocated_width (widget);
+		width += gtk_widget_get_margin_left (widget);
+		width += gtk_widget_get_margin_right (widget);
+	}
+
+	return width;
+}
+
+
+int
+_gtk_widget_get_allocated_height (GtkWidget *widget)
+{
+	int height = 0;
+
+	if ((widget != NULL) && gtk_widget_get_mapped (widget)) {
+		height = gtk_widget_get_allocated_height (widget);
+		height += gtk_widget_get_margin_top (widget);
+		height += gtk_widget_get_margin_bottom (widget);
+	}
+
+	return height;
+}
+
+
 void
 _gtk_tree_path_list_free (GList *list)
 {
@@ -993,9 +870,7 @@ _g_launch_command (GtkWidget  *parent,
 		return;
 	}
 
-	launch_context = gdk_app_launch_context_new ();
-	gdk_app_launch_context_set_screen (launch_context, gtk_widget_get_screen (parent));
-
+	launch_context = gdk_display_get_app_launch_context (gtk_widget_get_display (parent));
 	if (! g_app_info_launch (app_info, files, G_APP_LAUNCH_CONTEXT (launch_context), &error)) {
 		_gtk_error_dialog_from_gerror_show (GTK_WINDOW (parent), _("Could not launch the application"), error);
 		g_clear_error (&error);
@@ -1156,24 +1031,24 @@ gimp_scale_entry_new (GtkWidget *parent_box,
 		      float      page_increment,
 		      int        digits)
 {
-	GtkWidget *hbox;
-	GtkWidget *scale;
-	GtkWidget *spinbutton;
-	GtkObject *adj;
+	GtkAdjustment *adj;
+	GtkWidget     *spinbutton;
+	GtkWidget     *scale;
+	GtkWidget     *hbox;
 
 	adj = gtk_adjustment_new (value, lower, upper,
 				  step_increment, page_increment,
 				  0.0);
 
-	spinbutton = gtk_spin_button_new  (GTK_ADJUSTMENT (adj), page_increment, 0);
+	spinbutton = gtk_spin_button_new (GTK_ADJUSTMENT (adj), page_increment, 0);
 	gtk_spin_button_set_digits (GTK_SPIN_BUTTON (spinbutton), digits);
 	gtk_entry_set_width_chars (GTK_ENTRY (spinbutton), 4);
 
-	scale = gtk_hscale_new (GTK_ADJUSTMENT (adj));
+	scale = gtk_scale_new (GTK_ORIENTATION_HORIZONTAL, GTK_ADJUSTMENT (adj));
 	gtk_scale_set_draw_value (GTK_SCALE (scale), FALSE);
 	gtk_scale_set_digits (GTK_SCALE (scale), digits);
 
-	hbox = gtk_hbox_new (FALSE, 5);
+	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 5);
 	gtk_box_pack_start (GTK_BOX (hbox), scale, TRUE, TRUE, 0);
 	gtk_box_pack_start (GTK_BOX (hbox), spinbutton, FALSE, FALSE, 0);
 
@@ -1185,3 +1060,40 @@ gimp_scale_entry_new (GtkWidget *parent_box,
 
 	return (GtkAdjustment *) adj;
 }
+
+
+static gboolean
+_gdk_rgba_shade (GdkRGBA *color,
+		 GdkRGBA *result,
+		 gdouble  factor)
+{
+	GtkSymbolicColor *sym_color;
+	GtkSymbolicColor *sym_result;
+	gboolean          retval;
+
+	sym_color = gtk_symbolic_color_new_literal (color);
+	sym_result = gtk_symbolic_color_new_shade (sym_color, factor);
+
+	retval = gtk_symbolic_color_resolve (sym_result, NULL, result);
+
+	gtk_symbolic_color_unref (sym_result);
+	gtk_symbolic_color_unref (sym_color);
+
+	return retval;
+}
+
+
+gboolean
+_gdk_rgba_darker (GdkRGBA *color,
+		  GdkRGBA *result)
+{
+	return _gdk_rgba_shade (color, result, 0.8);
+}
+
+
+gboolean
+_gdk_rgba_lighter (GdkRGBA *color,
+		   GdkRGBA *result)
+{
+	return _gdk_rgba_shade (color, result, 1.2);
+}
